@@ -68,6 +68,19 @@ SKGTabPage* SKGDashboardPlugin::getWidget()
     return new SKGDashboardPluginWidget(m_currentDocument);
 }
 
+QWidget* SKGDashboardPlugin::getPreferenceWidget()
+{
+    SKGTRACEINFUNC(10);
+    auto w = new QWidget();
+    ui.setupUi(w);
+    return w;
+}
+
+KConfigSkeleton* SKGDashboardPlugin::getPreferenceSkeleton()
+{
+    return skgdashboard_settings::self();
+}
+
 QString SKGDashboardPlugin::title() const
 {
     return i18nc("Noun, a summary of your financial situation", "Dashboard");
