@@ -60,35 +60,35 @@ public:
      * @return a string containing all information needed to set the same state.
      * Could be an XML stream
      */
-    virtual QString getState() Q_DECL_OVERRIDE;
+    virtual QString getState() override;
 
     /**
      * Set the current state
      * MUST BE OVERWRITTEN
      * @param iState must be interpreted to set the state of the widget
      */
-    virtual void setState(const QString& iState) Q_DECL_OVERRIDE;
+    virtual void setState(const QString& iState) override;
 
     /**
      * Get attribute name to save the default state
      * MUST BE OVERWRITTEN
      * @return attribute name to save the default state.
      */
-    virtual QString getDefaultStateAttribute() Q_DECL_OVERRIDE;
+    virtual QString getDefaultStateAttribute() override;
 
     /**
      * Get the zoomable widget.
      * The default implementation returns the main widget.
      * @return the zoomable widget.
      */
-    virtual QWidget* zoomableWidget() Q_DECL_OVERRIDE;
+    virtual QWidget* zoomableWidget() override;
 
     /**
      * Get the printable widgets.
      * The default implementation returns the main widget.
      * @return the printable widgets.
      */
-    virtual QList<QWidget*> printableWidgets() Q_DECL_OVERRIDE;
+    virtual QList<QWidget*> printableWidgets() override;
 
 protected:
     /**
@@ -97,7 +97,7 @@ protected:
      * @param iEvent event
      * @return In your reimplementation of this function, if you want to filter the event out, i.e. stop it being handled further, return true; otherwise return false.
      */
-    virtual bool eventFilter(QObject* iObject, QEvent* iEvent) Q_DECL_OVERRIDE;
+    virtual bool eventFilter(QObject* iObject, QEvent* iEvent) override;
 
 public Q_SLOTS:
     /**
