@@ -21,9 +21,9 @@
  */
 #include "skgdebugpluginwidget.h"
 
-#include <QDomDocument>
-#include <QScriptEngine>
-#include <QJSEngine>
+#include <qdom.h>
+#include <qscriptengine.h>
+#include <qjsengine.h>
 
 #include "skgmainpanel.h"
 #include "skgdocument.h"
@@ -145,10 +145,11 @@ void SKGDebugPluginWidget::onExecuteSqlOrder(bool iInTransaction)
         // skgerror=skgdocument.sendMessage(QStringLiteral("Hello"))
         // skgerror=skgdocument.sendMessage(QStringLiteral("Hello"))
         // skgmainpanel.closeAllOtherPages(skgmainpanel.currentPage())
-        myEngine.globalObject().setProperty(QStringLiteral("skgresult"), myEngine.newQObject(ui.kSQLResult));
-        myEngine.globalObject().setProperty(QStringLiteral("skgdocument"), myEngine.newQObject(getDocument()));
-        myEngine.globalObject().setProperty(QStringLiteral("skgerror"), myEngine.newQObject(&err));
-        myEngine.globalObject().setProperty(QStringLiteral("skgmainpanel"), myEngine.newQObject(SKGMainPanel::getMainPanel()));
+        auto t = myEngine.globalObject();
+        t.setProperty(QStringLiteral("skgresult"), myEngine.newQObject(ui.kSQLResult));
+        t.setProperty(QStringLiteral("skgdocument"), myEngine.newQObject(getDocument()));
+        t.setProperty(QStringLiteral("skgerror"), myEngine.newQObject(&err));
+        t.setProperty(QStringLiteral("skgmainpanel"), myEngine.newQObject(SKGMainPanel::getMainPanel()));
 
         // Finally execute the scripting code.
         myEngine.evaluate(ui.kInput->toPlainText());
