@@ -21,12 +21,12 @@
  */
 #include "skgdeleteplugin.h"
 
-#include <QWidget>
+#include <qwidget.h>
 
-#include <KActionCollection>
-#include <KStandardAction>
+#include <kactioncollection.h>
+#include <kstandardaction.h>
 #include <kaboutdata.h>
-#include <KMessageBox>
+#include <kmessagebox.h>
 #include <kpluginfactory.h>
 #include <klocalizedstring.h>
 
@@ -42,7 +42,7 @@
 K_PLUGIN_FACTORY(SKGDeletePluginFactory, registerPlugin<SKGDeletePlugin>();)
 
 SKGDeletePlugin::SKGDeletePlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) :
-    SKGInterfacePlugin(iParent), m_currentDocument(NULL)
+    SKGInterfacePlugin(iParent), m_currentDocument(nullptr)
 {
     Q_UNUSED(iWidget);
     SKGTRACEINFUNC(10);
@@ -51,7 +51,7 @@ SKGDeletePlugin::SKGDeletePlugin(QWidget* iWidget, QObject* iParent, const QVari
 SKGDeletePlugin::~SKGDeletePlugin()
 {
     SKGTRACEINFUNC(10);
-    m_currentDocument = NULL;
+    m_currentDocument = nullptr;
 }
 
 bool SKGDeletePlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
@@ -67,7 +67,7 @@ bool SKGDeletePlugin::setupActions(SKGDocument* iDocument, const QStringList& iA
     // Menu
     QStringList tmp;
     m_currentDocument->getDistinctValues(QStringLiteral("sqlite_master"), QStringLiteral("name"), QStringLiteral("type='table' AND name!='parameters'"), tmp);
-    QAction* actDelete = new QAction(SKGServices::fromTheme(QStringLiteral("edit-delete")), i18nc("Verb, delete an item", "Delete"), this);
+    auto actDelete = new QAction(SKGServices::fromTheme(QStringLiteral("edit-delete")), i18nc("Verb, delete an item", "Delete"), this);
     connect(actDelete, &QAction::triggered, this, &SKGDeletePlugin::onDelete);
     actionCollection()->setDefaultShortcut(actDelete, Qt::Key_Delete);
     registerGlobalAction(QStringLiteral("edit_delete"), actDelete, tmp, 1, -1, 200);
