@@ -315,7 +315,7 @@ void SKGFilePlugin::onSaveAs()
     if (m_currentDocument && SKGMainPanel::getMainPanel()) {
         QString fileName = SKGMainPanel::getSaveFileName("kfiledialog:///" % m_currentDocument->objectName(),
                            "*." % m_currentDocument->getFileExtension() % '|' % i18nc("Associated with the file extension : for example, .csv --> CSV document", "%1 document", KAboutData::applicationData().displayName()) ,
-                           SKGMainPanel::getMainPanel(), nullptr);
+                           SKGMainPanel::getMainPanel());
         if (fileName.isEmpty()) {
             return;
         }
