@@ -188,7 +188,7 @@ void SKGMonthlyPluginWidget::onAddTemplate()
         SKGError err;
         if (!templates.contains(templatFileName)) {
             // Create the new template
-            QString source = QStandardPaths::locate(QStandardPaths::GenericDataLocation, KAboutData::applicationData().componentName() % "/html/default.txt");
+            QString source = QStandardPaths::locate(QStandardPaths::GenericDataLocation, KAboutData::applicationData().componentName() % "/html/tutorial.txt");
             QDir(templateDir).mkpath(QStringLiteral("html"));
             if (SKGServices::upload(QUrl::fromLocalFile(source), QUrl::fromLocalFile(templatFileName))) {
                 err.setReturnCode(ERR_FAIL).setMessage(i18nc("An error message", "Impossible to copy file from '%1' to '%2'", source, templatFileName));
