@@ -47,7 +47,7 @@
 K_PLUGIN_FACTORY(SKGPrintPluginFactory, registerPlugin<SKGPrintPlugin>();)
 
 SKGPrintPlugin::SKGPrintPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) :
-    SKGInterfacePlugin(iParent), m_currentDocument(NULL)
+    SKGInterfacePlugin(iParent), m_currentDocument(nullptr)
 {
     Q_UNUSED(iWidget);
     SKGTRACEINFUNC(10);
@@ -56,7 +56,7 @@ SKGPrintPlugin::SKGPrintPlugin(QWidget* iWidget, QObject* iParent, const QVarian
 SKGPrintPlugin::~SKGPrintPlugin()
 {
     SKGTRACEINFUNC(10);
-    m_currentDocument = NULL;
+    m_currentDocument = nullptr;
 }
 
 bool SKGPrintPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
@@ -189,42 +189,41 @@ void SKGPrintPlugin::print(QPrinter* iPrinter)
                                 QWidget* w = widgets.at(j);
                                 if (w) {
                                     // Add widget
-                                    SKGTreeView* tw = qobject_cast< SKGTreeView* >(w);
-                                    tw = NULL;
+                                    /*SKGTreeView* tw = qobject_cast< SKGTreeView* >(w);
                                     if (tw) {
                                         QTextBrowser* tb = tw->getTextBrowser();
                                         if (tb) {
                                             html = html % tb->toHtml();
                                             delete tb;
                                         }
+                                    } else {*/
+                                    QWebView* q = qobject_cast< QWebView* >(w);
+                                    if (q) {
+                                        html = html % q->page()->currentFrame()->toHtml();
                                     } else {
-                                        QWebView* q = qobject_cast< QWebView* >(w);
-                                        if (q) {
-                                            html = html % q->page()->currentFrame()->toHtml();
-                                        } else {
-                                            // Save palette
-                                            QPalette previousPalette = w->palette();
+                                        // Save palette
+                                        QPalette previousPalette = w->palette();
 
-                                            // Draw in a picture with white background
-                                            QImage image(w->size(), QImage::Format_ARGB32);
-                                            QPainter painter2(&image);
-                                            QPalette palette;
-                                            palette.setColor(QPalette::Background, Qt::white);
-                                            w->setPalette(palette);
-                                            w->render(&painter2);
-                                            painter2.end();
+                                        // Draw in a picture with white background
+                                        QImage image(w->size(), QImage::Format_ARGB32);
+                                        QPainter painter2(&image);
+                                        QPalette palette;
+                                        palette.setColor(QPalette::Background, Qt::white);
+                                        w->setPalette(palette);
+                                        w->render(&painter2);
+                                        painter2.end();
 
-                                            // Restore palette
-                                            w->setPalette(previousPalette);
+                                        // Restore palette
+                                        w->setPalette(previousPalette);
 
-                                            QByteArray byteArray;
-                                            QBuffer buffer(&byteArray);
-                                            image.save(&buffer, "PNG");
+                                        QByteArray byteArray;
+                                        QBuffer buffer(&byteArray);
+                                        image.save(&buffer, "PNG");
 
-                                            QString imgBase64 = QString::fromLatin1(byteArray.toBase64().data());
-                                            html = html % "<img src=\"data:image/png;base64," % imgBase64 % "\" />";
-                                        }
+                                        QString imgBase64 = QString::fromLatin1(byteArray.toBase64().data());
+                                        html = html % "<img src=\"data:image/png;base64," % imgBase64 % "\" />";
                                     }
+                                    // }
                                 }
                             }
                         }
