@@ -26,6 +26,7 @@
 #include <qfile.h>
 #include <qdesktopservices.h>
 #include <qfiledialog.h>
+#include <qlineedit.h>
 
 #include "skgmainpanel.h"
 #include "skgtraces.h"
@@ -60,6 +61,9 @@ SKGPropertiesPluginDockWidget::SKGPropertiesPluginDockWidget(SKGDocument* iDocum
     ui.kSelectFile->setIcon(SKGServices::fromTheme(QStringLiteral("document-open")));
     ui.kOpenBtn->setIcon(SKGServices::fromTheme(QStringLiteral("quickopen")));
 
+    ui.kAttribute->lineEdit()->setPlaceholderText(i18n("Name"));
+    ui.kValue->lineEdit()->setPlaceholderText(i18n("Value"));
+
     ui.kForCmb->addItem(i18n("Selection"));
     ui.kForCmb->addItem(i18n("All"));
 
@@ -200,7 +204,7 @@ void SKGPropertiesPluginDockWidget::onOpenFile()
         QUrl url = obj.getUrl(true);
 
         if (!url.scheme().isEmpty() && !QDesktopServices::openUrl(url)) {
-            QString fileNameToSave = SKGMainPanel::getSaveFileName(QStringLiteral("kfiledialog:///IMPEXP"), QStringLiteral("") , SKGMainPanel::getMainPanel(), nullptr);
+            QString fileNameToSave = SKGMainPanel::getSaveFileName(QStringLiteral("kfiledialog:///IMPEXP"), QStringLiteral("") , SKGMainPanel::getMainPanel());
             if (!fileNameToSave.isEmpty()) {
                 QFile(url.toLocalFile()).copy(fileNameToSave);
             }
