@@ -21,13 +21,13 @@
  */
 #include "skgselectallplugin.h"
 
-#include <KActionCollection>
-#include <KStandardAction>
+#include <kactioncollection.h>
+#include <kstandardaction.h>
 #include <kaboutdata.h>
 #include <kpluginfactory.h>
 #include <klocalizedstring.h>
 
-#include <QAbstractItemView>
+#include <qabstractitemview.h>
 
 #include "skgmainpanel.h"
 #include "skgtreeview.h"
@@ -38,16 +38,22 @@
 K_PLUGIN_FACTORY(SKGSelectAllPluginFactory, registerPlugin<SKGSelectAllPlugin>();)
 
 SKGSelectAllPlugin::SKGSelectAllPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) :
-    SKGInterfacePlugin(iParent), m_currentDocument(NULL)
+    SKGInterfacePlugin(iParent), m_currentDocument(nullptr), m_selectionMessage(nullptr)
 {
     Q_UNUSED(iWidget);
     SKGTRACEINFUNC(10);
+
+    connect(SKGMainPanel::getMainPanel(), &SKGMainPanel::selectionChanged, this, &SKGSelectAllPlugin::onSelectionChanged);
 }
 
 SKGSelectAllPlugin::~SKGSelectAllPlugin()
 {
     SKGTRACEINFUNC(10);
-    m_currentDocument = NULL;
+    m_currentDocument = nullptr;
+    if (m_selectionMessage) {
+        delete m_selectionMessage;
+        m_selectionMessage = nullptr;
+    }
 }
 
 bool SKGSelectAllPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
@@ -62,7 +68,6 @@ bool SKGSelectAllPlugin::setupActions(SKGDocument* iDocument, const QStringList&
 
     // Menu
     registerGlobalAction(QStringLiteral("edit_select_all"), actionCollection()->addAction(KStandardAction::SelectAll, QStringLiteral("edit_select_all"), this, SLOT(onSelectAll())), QStringList(), -1);
-
     return true;
 }
 
@@ -92,6 +97,38 @@ QStringList SKGSelectAllPlugin::tips() const
     return output;
 }
 
+void SKGSelectAllPlugin::onSelectionChanged()
+{
+    SKGTRACEINFUNC(10);
+    if (SKGMainPanel::getMainPanel()) {
+        if (!m_selectionMessage) {
+            // Add statusbar
+            m_selectionMessage = new QLabel(SKGMainPanel::getMainPanel());
+            SKGMainPanel::getMainPanel()->statusBar()->insertPermanentWidget(1, m_selectionMessage);
+        }
+        SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
+        int nb = selection.count();
+        if (nb) {
+            double sum = 0.0;
+            bool computed = false;
+            for (int i = 0; i < nb; ++i) {
+                SKGObjectBase obj(selection.at(i));
+                QString val = obj.getAttribute(QStringLiteral("f_REALCURRENTAMOUNT"));
+                if (val.isEmpty()) {
+                    val = obj.getAttribute(QStringLiteral("f_CURRENTAMOUNT"));
+                }
+                if (!val.isEmpty()) {
+                    sum += SKGServices::stringToDouble(val);
+                    computed = true;
+                }
+            }
+            m_selectionMessage->setText(computed ? i18np("Selection: %1 line for %2", "Selection: %1 lines for %2", nb, m_currentDocument->formatPrimaryMoney(sum)) : i18np("Selection: %1 line", "Selection: %1 lines", nb));
+        } else {
+            m_selectionMessage->clear();
+        }
+    }
+}
+
 void SKGSelectAllPlugin::onSelectAll()
 {
     SKGTRACEINFUNC(10);
