@@ -158,7 +158,7 @@ SKGError SKGImportPluginAFB120::importFile()
                             // Operation
                             QString unitCode = line.mid(17 - 1, 3);
                             QString nbDecimal = line.mid(20 - 1, 1);
-                            QString codeMode = line.mid(33 - 1, 2);
+                            // QString codeMode = line.mid(33 - 1, 2);
                             QString dateJJMMAA = line.mid(35 - 1, 6);
                             QString comment = line.mid(49 - 1, 31).trimmed();
                             QString amount = line.mid(91 - 1, 14);
