@@ -27,7 +27,6 @@
 
 #include <qdom.h>
 #include <qfileinfo.h>
-#include <math.h>
 #include <cmath>
 
 #include "skgtraces.h"
@@ -37,11 +36,6 @@
 #include "skgpayeeobject.h"
 #include "skgimportexportmanager.h"
 
-#ifdef Q_OS_WIN
-#define isnan(a) _isnan(a)
-#define isinf(a) !_finite(a)
-#endif
-
 /**
  * This plugin factory.
  */
@@ -386,7 +380,7 @@ SKGError SKGImportPluginGnc::importFile()
                                         }
                                     }
 
-                                    if (!isnan(info.value)) {
+                                    if (!std::isnan(info.value)) {
                                         QChar accountType = mapIdType[info.account.text()];
                                         if (accountType == 'C') {
                                             suboperationsList.push_front(info);
