@@ -22,10 +22,10 @@
 #include "skgimportplugingsb.h"
 
 #include <klocalizedstring.h>
-#include <KCompressionDevice>
+#include <kcompressiondevice.h>
 #include <kpluginfactory.h>
 
-#include <QDomDocument>
+#include <qdom.h>
 #include <qfileinfo.h>
 
 #include "skgtraces.h"
@@ -424,7 +424,7 @@ SKGError SKGImportPluginGsb::importFile()
 
                         SKGObjectBase::SKGListSKGObjectBase subObjs2;
                         IFOKDO(err, opObj2.getSubOperations(subObjs2))
-                        if (!err && subObjs2.count()) {
+                        if (!err && !subObjs2.isEmpty()) {
                             SKGSubOperationObject subObj2(subObjs2.at(0));
                             err = subObj2.setQuantity(-subObj.getQuantity());
                             IFOKDO(err, subObj2.save())
@@ -441,7 +441,7 @@ SKGError SKGImportPluginGsb::importFile()
                     IFOKDO(err, recuObj.setAutoWriteDays(0))
                     IFOKDO(err, recuObj.autoWriteEnabled(getAttribute(transaction, QStringLiteral("Au")) != QStringLiteral("0")))
                     IFOK(err) {
-                        // text_frequency [] = { _("Once"), _("Weekly"), _("Monthly"), _("two months"), ("trimester"), _("Yearly"), _("Custom"), NULL };
+                        // text_frequency [] = { _("Once"), _("Weekly"), _("Monthly"), _("two months"), ("trimester"), _("Yearly"), _("Custom"), nullptr };
                         int occu = 1;
                         SKGRecurrentOperationObject::PeriodUnit period = SKGRecurrentOperationObject::DAY;
                         QString Pe = getAttribute(transaction,  QStringLiteral("Pe"));
@@ -463,7 +463,7 @@ SKGError SKGImportPluginGsb::importFile()
                         } else if (Pe == QStringLiteral("5")) {
                             period = SKGRecurrentOperationObject::YEAR;
                         } else if (Pe == QStringLiteral("6")) {
-                            // text_frequency_user [] = { _("Days"), _("Weeks"), _("Months"), _("Years"), NULL };
+                            // text_frequency_user [] = { _("Days"), _("Weeks"), _("Months"), _("Years"), nullptr };
                             occu = SKGServices::stringToInt(getAttribute(transaction,  QStringLiteral("Pep")));
                             QString Pei = getAttribute(transaction,  QStringLiteral("Pei"));
                             if (Pei == QStringLiteral("0")) {
