@@ -344,7 +344,7 @@ SKGError SKGImportPluginMmb::importFile()
 
                                 SKGObjectBase::SKGListSKGObjectBase subops;
                                 IFOKDO(err, op.getSubOperations(subops))
-                                if (!err && subops.count()) {
+                                if (!err && !subops.isEmpty()) {
                                     SKGSubOperationObject subop2(subops.at(0));
                                     err = subop2.setQuantity(-subop2.getQuantity());
                                     IFOKDO(err, subop2.save())
