@@ -52,7 +52,7 @@ SKGImportPluginMT940::~SKGImportPluginMT940()
 bool SKGImportPluginMT940::isImportPossible()
 {
     SKGTRACEINFUNC(10);
-    return (!m_importer ? true : m_importer->getFileNameExtension() == "MT940");
+    return (!m_importer ? true : m_importer->getFileNameExtension() == QStringLiteral("MT940"));
 }
 
 SKGError SKGImportPluginMT940::importFile()
@@ -99,7 +99,7 @@ SKGError SKGImportPluginMT940::importFile()
                 SKGAccountObject account;
                 SKGOperationObject operation;
                 SKGUnitObject unit;
-                QString bankName = "MT940";
+                QString bankName = QStringLiteral("MT940");
 
                 int nb = lines.count();
                 IFOKDO(err, m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import operations"), nb))
@@ -115,7 +115,7 @@ SKGError SKGImportPluginMT940::importFile()
                             if (line.startsWith(QLatin1String(":25:"))) {
                                 // Account
                                 QStringList vals = SKGServices::splitCSVLine(line.right(line.count() - 4), '/');
-                                QString name = "MT940";
+                                QString name = QStringLiteral("MT940");
                                 QString number = name;
                                 if (vals.count() == 2) {
                                     bankName = vals.at(0);
@@ -128,7 +128,7 @@ SKGError SKGImportPluginMT940::importFile()
 
                                 // Search if account is already existing
                                 SKGObjectBase::SKGListSKGObjectBase listAccount;
-                                err = m_importer->getDocument()->getObjects("v_account", "t_number='" % number % '\'', listAccount);
+                                err = m_importer->getDocument()->getObjects(QStringLiteral("v_account"), "t_number='" % number % '\'', listAccount);
                                 IFOK(err) {
                                     if (listAccount.count() == 1) {
                                         // Yes ! Only one account found
@@ -178,7 +178,7 @@ SKGError SKGImportPluginMT940::importFile()
                             } else if (line.startsWith(QLatin1String(":61:"))) {
                                 // Example :61:0712280103D000000000200,00FMSCNONREF
                                 QString val = line.right(line.count() - 4);
-                                QDate date = QDate::fromString(val.left(6), "yyMMdd");
+                                QDate date = QDate::fromString(val.left(6), QStringLiteral("yyMMdd"));
                                 if (date.year() < 1970) {
                                     date = date.addYears(100);
                                 }
@@ -204,7 +204,7 @@ SKGError SKGImportPluginMT940::importFile()
                                 err = account.addOperation(operation, true);
                                 IFOKDO(err, operation.setDate(date))
                                 IFOKDO(err, operation.setUnit(unit))
-                                IFOKDO(err, operation.setAttribute("t_imported", "T"))
+                                IFOKDO(err, operation.setAttribute(QStringLiteral("t_imported"), QStringLiteral("T")))
                                 // if(!err) err = operation.setImportID("MT940");
                                 IFOKDO(err, operation.save())
 
