@@ -681,27 +681,6 @@ void SKGBankPluginWidget::onModifyAccountClicked()
     ui.kView->getView()->setFocus();
 }
 
-void SKGBankPluginWidget::onComputeRIB()
-{
-    QString sb = ui.kAccountCreatorBankNumber->text().rightJustified(5, '0', true);
-    QString sg = ui.kAccountCreatorAgencyNumber->text().rightJustified(5, '0', true);
-    QString sc = ui.kAccountCreatorNumber->text().rightJustified(11, '0', true);
-
-    QString l1 = QStringLiteral("ABCDEFGHIJKLMNOPQRSTUVWXYZ");
-    QString l2 = QStringLiteral("12345678912345678923456789");
-
-    for (int i = 0; i < 26; ++i) {
-        sc = sc.replace(l1.at(i), l2.at(i));
-    }
-
-    //         int b=SKGServices::stringToInt ( sb );
-    //         int g=SKGServices::stringToInt ( sg );
-    //         int d=SKGServices::stringToInt ( sc.left ( 6 ) );
-    //         int c=SKGServices::stringToInt ( sc.right ( 5 ) );
-
-    //         ui.kRib->setText ( SKGServices::intToString ( 97 - ( ( 89 * b + 15 * g + 76 * d + 3 * c ) % 97 ) ) );
-}
-
 void SKGBankPluginWidget::cleanEditor()
 {
     if (getNbSelectedObjects() == 0) {
