@@ -23,8 +23,8 @@
 
 #include <kcolorscheme.h>
 
-#include <QSortFilterProxyModel>
-#include <QPainter>
+#include <qsortfilterproxymodel.h>
+#include <qpainter.h>
 
 #include "skgobjectmodelbase.h"
 #include "skgtraces.h"
@@ -35,7 +35,7 @@ SKGBudgetDelegate::SKGBudgetDelegate(QObject* iParent, SKGDocument* iDoc) : QSty
 
 SKGBudgetDelegate::~SKGBudgetDelegate()
 {
-    m_document = NULL;
+    m_document = nullptr;
 }
 
 void SKGBudgetDelegate::paint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const
