@@ -21,8 +21,8 @@
  */
 #include "skgbudgetplugin.h"
 
-#include <KActionCollection>
-#include <KStandardAction>
+#include <kactioncollection.h>
+#include <kstandardaction.h>
 #include <kaboutdata.h>
 #include <kpluginfactory.h>
 #include <klocalizedstring.h>
@@ -40,7 +40,7 @@
  */
 K_PLUGIN_FACTORY(SKGBudgetPluginFactory, registerPlugin<SKGBudgetPlugin>();)
 
-SKGBudgetPlugin::SKGBudgetPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
+SKGBudgetPlugin::SKGBudgetPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent), m_currentBankDocument(nullptr)
 {
     Q_UNUSED(iWidget);
     SKGTRACEINFUNC(10);
@@ -49,7 +49,7 @@ SKGBudgetPlugin::SKGBudgetPlugin(QWidget* iWidget, QObject* iParent, const QVari
 SKGBudgetPlugin::~SKGBudgetPlugin()
 {
     SKGTRACEINFUNC(10);
-    m_currentBankDocument = NULL;
+    m_currentBankDocument = nullptr;
 }
 
 bool SKGBudgetPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
@@ -57,7 +57,7 @@ bool SKGBudgetPlugin::setupActions(SKGDocument* iDocument, const QStringList& iA
     SKGTRACEINFUNC(10);
     Q_UNUSED(iArgument);
     m_currentBankDocument = qobject_cast<SKGDocumentBank*>(iDocument);
-    if (m_currentBankDocument == NULL) {
+    if (m_currentBankDocument == nullptr) {
         return false;
     }
 
@@ -68,7 +68,7 @@ bool SKGBudgetPlugin::setupActions(SKGDocument* iDocument, const QStringList& iA
     // -----------
     QStringList overlayrun;
     overlayrun.push_back(QStringLiteral("system-run"));
-    QAction* act = new QAction(SKGServices::fromTheme(icon(), overlayrun), i18nc("Verb", "Process budget rules"), this);
+    auto act = new QAction(SKGServices::fromTheme(icon(), overlayrun), i18nc("Verb", "Process budget rules"), this);
     connect(act, &QAction::triggered, this, &SKGBudgetPlugin::onProcessRules);
     registerGlobalAction(QStringLiteral("tool_process_budget_rules"), act);
     return true;
