@@ -21,8 +21,8 @@
  */
 #include "skgbudgetpluginwidget.h"
 
-#include <QDomDocument>
-#include <QKeyEvent>
+#include <qdom.h>
+#include <qevent.h>
 
 #include "skgbudgetdelegate.h"
 #include "skgmainpanel.h"
@@ -35,7 +35,7 @@
 #include "skgdocument.h"
 
 SKGBudgetPluginWidget::SKGBudgetPluginWidget(SKGDocument* iDocument)
-    : SKGTabPage(iDocument)
+    : SKGTabPage(iDocument), m_objectModel(nullptr)
 {
     SKGTRACEINFUNC(1);
     if (!iDocument) {
@@ -188,7 +188,7 @@ SKGBudgetPluginWidget::SKGBudgetPluginWidget(SKGDocument* iDocument)
 SKGBudgetPluginWidget::~SKGBudgetPluginWidget()
 {
     SKGTRACEINFUNC(1);
-    m_objectModel = NULL;
+    m_objectModel = nullptr;
 }
 
 bool SKGBudgetPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
@@ -264,8 +264,8 @@ void SKGBudgetPluginWidget::refresh()
     SKGTRACEINFUNC(1);
 
     QSqlDatabase* db = getDocument()->getDatabase();
-    setEnabled(db != NULL);
-    if (db != NULL) {
+    setEnabled(db != nullptr);
+    if (db != nullptr) {
         // Refresh yours widgets here
     }
 }
@@ -451,6 +451,9 @@ void SKGBudgetPluginWidget::onUpdateClicked()
 
     // Display error
     SKGMainPanel::displayErrorMessage(err);
+
+    // Set focus on table
+    ui.kView->getView()->setFocus();
 }
 
 SKGError SKGBudgetPluginWidget::updateBudget(SKGBudgetObject& iBudget, int iMonth)
