@@ -53,38 +53,38 @@ public:
      * @return a string containing all information needed to set the same state.
      * Could be an XML stream
      */
-    virtual QString getState() Q_DECL_OVERRIDE;
+    virtual QString getState() override;
 
     /**
      * Set the current state
      * MUST BE OVERWRITTEN
      * @param iState must be interpreted to set the state of the widget
      */
-    virtual void setState(const QString& iState) Q_DECL_OVERRIDE;
+    virtual void setState(const QString& iState) override;
 
     /**
      * Get attribute name to save the default state
      * MUST BE OVERWRITTEN
      * @return attribute name to save the default state.
      */
-    virtual QString getDefaultStateAttribute() Q_DECL_OVERRIDE;
+    virtual QString getDefaultStateAttribute() override;
 
     /**
      * Get the main widget
      * @return a widget
      */
-    virtual QWidget* mainWidget() Q_DECL_OVERRIDE;
+    virtual QWidget* mainWidget() override;
 
     /**
      * To know if this page contains an editor. MUST BE OVERWRITTEN
      * @return the editor state
      */
-    virtual bool isEditor() Q_DECL_OVERRIDE;
+    virtual bool isEditor() override;
 
     /**
      * To activate the editor by setting focus on right widget. MUST BE OVERWRITTEN
      */
-    virtual void activateEditor() Q_DECL_OVERRIDE;
+    virtual void activateEditor() override;
 
 public Q_SLOTS:
     /**
@@ -99,7 +99,7 @@ protected:
      * @param iEvent event
      * @return In your reimplementation of this function, if you want to filter the event out, i.e. stop it being handled further, return true; otherwise return false.
      */
-    virtual bool eventFilter(QObject* iObject, QEvent* iEvent) Q_DECL_OVERRIDE;
+    virtual bool eventFilter(QObject* iObject, QEvent* iEvent) override;
 
 private Q_SLOTS:
     void dataModified(const QString& iTableName, int iIdTransaction, bool iLightTransaction = false);
