@@ -21,8 +21,8 @@
  */
 #include "skgcalculatorplugin.h"
 
-#include <KActionCollection>
-#include <KStandardAction>
+#include <kactioncollection.h>
+#include <kstandardaction.h>
 #include <kaboutdata.h>
 #include <kpluginfactory.h>
 
@@ -37,7 +37,7 @@
  */
 K_PLUGIN_FACTORY(SKGCalculatorPluginFactory, registerPlugin<SKGCalculatorPlugin>();)
 
-SKGCalculatorPlugin::SKGCalculatorPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
+SKGCalculatorPlugin::SKGCalculatorPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent), m_currentBankDocument(nullptr)
 {
     Q_UNUSED(iWidget);
     SKGTRACEINFUNC(10);
@@ -46,7 +46,7 @@ SKGCalculatorPlugin::SKGCalculatorPlugin(QWidget* iWidget, QObject* iParent, con
 SKGCalculatorPlugin::~SKGCalculatorPlugin()
 {
     SKGTRACEINFUNC(10);
-    m_currentBankDocument = NULL;
+    m_currentBankDocument = nullptr;
 }
 
 bool SKGCalculatorPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
@@ -54,7 +54,7 @@ bool SKGCalculatorPlugin::setupActions(SKGDocument* iDocument, const QStringList
     SKGTRACEINFUNC(10);
     Q_UNUSED(iArgument);
     m_currentBankDocument = qobject_cast<SKGDocumentBank*>(iDocument);
-    if (m_currentBankDocument == NULL) {
+    if (m_currentBankDocument == nullptr) {
         return false;
     }
 
