@@ -21,9 +21,9 @@
  */
 #include "skgcalculatorpluginwidget.h"
 
-#include <QDomDocument>
+#include <qdom.h>
 #include <qdir.h>
-#include <QKeyEvent>
+#include <qevent.h>
 #include <qmath.h>
 #include <qstandardpaths.h>
 
@@ -37,7 +37,7 @@
 #include "skgunitobject.h"
 
 SKGCalculatorPluginWidget::SKGCalculatorPluginWidget(SKGDocumentBank* iDocument)
-    : SKGTabPage(iDocument)
+    : SKGTabPage(iDocument), m_objectModel(nullptr)
 {
     SKGTRACEINFUNC(1);
     if (!iDocument) {
@@ -86,7 +86,7 @@ SKGCalculatorPluginWidget::SKGCalculatorPluginWidget(SKGDocumentBank* iDocument)
     m_objectModel = new SKGObjectModel(static_cast<SKGDocumentBank*>(getDocument()), QStringLiteral("v_interest"), QStringLiteral(""), this, QStringLiteral(""), false);
     ui.kInterestView->setModel(m_objectModel);
 
-    SKGObjectModel* resultModel = new SKGObjectModel(static_cast<SKGDocumentBank*>(getDocument()), QStringLiteral("interest_result"), QStringLiteral(""), this, QStringLiteral(""), false);
+    auto resultModel = new SKGObjectModel(static_cast<SKGDocumentBank*>(getDocument()), QStringLiteral("interest_result"), QStringLiteral(""), this, QStringLiteral(""), false);
     ui.kInterestResultTable->setModel(resultModel);
 
     connect(ui.kInterestView, &SKGTableView::selectionChangedDelayed, this, &SKGCalculatorPluginWidget::onSelectionChanged);
@@ -113,7 +113,7 @@ SKGCalculatorPluginWidget::SKGCalculatorPluginWidget(SKGDocumentBank* iDocument)
 SKGCalculatorPluginWidget::~SKGCalculatorPluginWidget()
 {
     SKGTRACEINFUNC(1);
-    m_objectModel = NULL;
+    m_objectModel = nullptr;
 }
 
 bool SKGCalculatorPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
@@ -238,7 +238,7 @@ void SKGCalculatorPluginWidget::onSelectionChanged()
     QItemSelectionModel* selModel = ui.kInterestView->selectionModel();
     if (selModel) {
         QModelIndexList indexes = selModel->selectedRows();
-        if (indexes.count() && m_objectModel) {
+        if (indexes.isEmpty() == false && m_objectModel) {
             QModelIndex idx = indexes[indexes.count() - 1];
 
             SKGInterestObject interest(m_objectModel->getObject(idx));
@@ -263,8 +263,8 @@ void SKGCalculatorPluginWidget::dataModified(const QString& iTableName, int iIdT
 
     // Refresh widgets
     QSqlDatabase* db = getDocument()->getDatabase();
-    setEnabled(db != NULL);
-    if (db != NULL && (iTableName == QStringLiteral("interest") || iTableName.isEmpty())) {
+    setEnabled(db != nullptr);
+    if (db != nullptr && (iTableName == QStringLiteral("interest") || iTableName.isEmpty())) {
         // Correction bug 2299394 vvv
         if (ui.kInterestView->isAutoResized()) {
             ui.kInterestView->resizeColumnsToContentsDelayed();
@@ -278,7 +278,7 @@ void SKGCalculatorPluginWidget::dataModified(const QString& iTableName, int iIdT
 
     // Refresh interest parameter view
     QString current = ui.kDisplayAccountCombo->currentText();
-    if (db != NULL && (iTableName == QStringLiteral("v_account_display") || iTableName.isEmpty())) {
+    if (db != nullptr && (iTableName == QStringLiteral("v_account_display") || iTableName.isEmpty())) {
         // Clear
         ui.kDisplayAccountCombo->clear();
 
@@ -305,7 +305,7 @@ void SKGCalculatorPluginWidget::dataModified(const QString& iTableName, int iIdT
     }
 
     // Fill years
-    if (db != NULL && (iTableName == QStringLiteral("v_operation_display") || iTableName.isEmpty())) {
+    if (db != nullptr && (iTableName == QStringLiteral("v_operation_display") || iTableName.isEmpty())) {
         disconnect(ui.KYearEdit, static_cast<void (SKGComboBox::*)(const QString&)>(&SKGComboBox::currentIndexChanged), this, &SKGCalculatorPluginWidget::onFilterChanged);
 
         int lastYear = QDate::currentDate().year();
@@ -331,7 +331,7 @@ void SKGCalculatorPluginWidget::dataModified(const QString& iTableName, int iIdT
         connect(ui.KYearEdit, static_cast<void (SKGComboBox::*)(const QString&)>(&SKGComboBox::currentIndexChanged), this, &SKGCalculatorPluginWidget::onFilterChanged);
     }
     // Refresh computation
-    if (db != NULL && (iTableName == QStringLiteral("interest") || iTableName == QStringLiteral("account") || iTableName.isEmpty())) {
+    if (db != nullptr && (iTableName == QStringLiteral("interest") || iTableName == QStringLiteral("account") || iTableName.isEmpty())) {
         computeInterest();
     }
     QApplication::restoreOverrideCursor();
@@ -536,8 +536,8 @@ void SKGCalculatorPluginWidget::onAmortizationComputation()
     int periodInMonths = 12;
     int numberPayments = ui.kLenghtEdit->value() * periodInMonths;
     double periodicRate = ui.kAnnualRateEdit->value() / 100 / periodInMonths;
-    double insurance = qRound(ui.kLoanEdit->value() * ui.kInsuranceRateEdit->value() / 100 / periodInMonths * p) / p;
-    double periodicAmount = qRound(ui.kLoanEdit->value() * periodicRate / (1 - pow(1 + periodicRate, -numberPayments)) * p) / p;
+    double insurance = qRound(ui.kLoanEdit->value() * ui.kInsuranceRateEdit->value() / 100.0 / static_cast<double>(periodInMonths) * static_cast<double>(p)) / static_cast<double>(p);
+    double periodicAmount = qRound(ui.kLoanEdit->value() * periodicRate / (1 - pow(1 + periodicRate, -numberPayments)) * static_cast<double>(p)) / static_cast<double>(p);
 
     // Fill table
     double dueAmount = ui.kLoanEdit->value();
@@ -545,8 +545,8 @@ void SKGCalculatorPluginWidget::onAmortizationComputation()
     ui.kAmortizationTable->setRowCount(numberPayments);
     for (int i = 0; i < numberPayments; ++i) {
         // Compute
-        double roundedInterest = qRound(dueAmount * periodicRate * p) / p;
-        double principal = qRound((i == numberPayments - 1 ? dueAmount : periodicAmount - roundedInterest) * p) / p;
+        double roundedInterest = qRound(dueAmount * periodicRate * static_cast<double>(p)) / static_cast<double>(p);
+        double principal = qRound((i == numberPayments - 1 ? dueAmount : periodicAmount - roundedInterest) * p) / static_cast<double>(p);
         double amount = roundedInterest + principal;
         dueAmount -= principal;
         sumInterest += roundedInterest;
