@@ -150,25 +150,30 @@ QString SKGCategoriesPlugin::getDashboardWidgetTitle(int iIndex)
 SKGBoardWidget* SKGCategoriesPlugin::getDashboardWidget(int iIndex)
 {
     SKGTRACEINFUNC(1);
+    // Get QML mode for dashboard
+    KConfigSkeleton* skl = SKGMainPanel::getMainPanel()->getPluginByName(QStringLiteral("Dashboard plugin"))->getPreferenceSkeleton();
+    KConfigSkeletonItem* sklItem = skl->findItem(QStringLiteral("qmlmode"));
+    bool qml = sklItem->property().toBool();
+
     if (iIndex == 0)  {
         return new SKGHtmlBoardWidget(m_currentBankDocument,
                                       getDashboardWidgetTitle(iIndex),
-                                      QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/categories_period_table.html")),
+                                      QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/categories_period_table.") % (qml ?  QStringLiteral("qml") :  QStringLiteral("html"))),
                                       QStringList() << QStringLiteral("v_suboperation_consolidated"), SKGSimplePeriodEdit::ALL_PERIODS);
     } else if (iIndex == 1) {
         return new SKGHtmlBoardWidget(m_currentBankDocument,
-                                      getDashboardWidgetTitle(iIndex),
-                                      QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/categories_variations.html")),
+                                      getDashboardWidgetTitle(iIndex) % " - %1",
+                                      QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/categories_variations.") % (qml ?  QStringLiteral("qml") :  QStringLiteral("html"))),
                                       QStringList() << QStringLiteral("v_suboperation_consolidated"), SKGSimplePeriodEdit::PREVIOUS_AND_CURRENT_PERIODS);
     } else if (iIndex == 2) {
         return new SKGHtmlBoardWidget(m_currentBankDocument,
-                                      getDashboardWidgetTitle(iIndex),
+                                      getDashboardWidgetTitle(iIndex) % " - %1",
                                       QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/budget_table.html")),
                                       QStringList() << QStringLiteral("v_budget"), SKGSimplePeriodEdit::PREVIOUS_AND_CURRENT_MONTHS);
     }
     return new SKGHtmlBoardWidget(m_currentBankDocument,
-                                  getDashboardWidgetTitle(iIndex),
-                                  QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/categories_variations_issues.html")),
+                                  getDashboardWidgetTitle(iIndex) % " - %1",
+                                  QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/categories_variations_issues.") % (qml ?  QStringLiteral("qml") :  QStringLiteral("html"))),
                                   QStringList() << QStringLiteral("v_suboperation_consolidated"), SKGSimplePeriodEdit::PREVIOUS_AND_CURRENT_PERIODS);
 }
 
