@@ -244,7 +244,8 @@ QWidget* SKGImportExportPlugin::getPreferenceWidget()
     // Build list of known backends
     QStringList backends;
     QString a = QStringLiteral("skrooge/backends");
-    for (const auto& dir : QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, a, QStandardPaths::LocateDirectory)) {
+    const auto dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, a, QStandardPaths::LocateDirectory);
+    for (const auto& dir : dirs) {
         QDirIterator it(dir, QStringList() << QStringLiteral("*.backend"));
         while (it.hasNext()) {
             backends.push_back(QFileInfo(it.next()).baseName().toLower());
@@ -441,7 +442,7 @@ void SKGImportExportPlugin::import(const QList<QUrl>& iFiles, int mode)
                                                  SKGMainPanel::getMainPanel());
             const auto urls = result.URLs;
             fileNames.reserve(urls.count());
-            for (const auto& u : urls) {
+            for (const auto& u : qAsConst(urls)) {
                 fileNames.append(QUrl(u.url()));
             }
             codec = result.encoding;
@@ -892,7 +893,7 @@ SKGAdviceList SKGImportExportPlugin::advice(const QStringList& iIgnoredAdvice)
                 ad.setShortMessage(i18nc("Advice on making the best (short)", "Krunner's operation ongoing [%1 %2 %3]", date, amount, payee));
                 ad.setLongMessage(i18nc("Advice on making the best (long)", "Operations created through krunner have to be fully created in skrooge."));
                 SKGAdvice::SKGAdviceActionList autoCorrections;
-                autoCorrections.reserve(2 * nbAccounts);
+                autoCorrections.reserve(nbAccounts + 1);
                 for (int j = 0; j < nbAccounts; ++j) {
                     SKGAdvice::SKGAdviceAction a;
                     a.Title = i18nc("Advice on making the best (action)", "Import operation in %1", listAccounts.at(j));
