@@ -32,6 +32,7 @@
 
 #include "skgoperationpluginwidget.h"
 #include "skgoperationboardwidget.h"
+#include "skgoperationboardwidgetqml.h"
 #include "skgtraces.h"
 #include "skgoperationobject.h"
 #include "skgaccountobject.h"
@@ -370,8 +371,17 @@ QString SKGOperationPlugin::getDashboardWidgetTitle(int iIndex)
 
 SKGBoardWidget* SKGOperationPlugin::getDashboardWidget(int iIndex)
 {
+    // Get QML mode for dashboard
+    KConfigSkeleton* skl = SKGMainPanel::getMainPanel()->getPluginByName(QStringLiteral("Dashboard plugin"))->getPreferenceSkeleton();
+    KConfigSkeletonItem* sklItem = skl->findItem(QStringLiteral("qmlmode"));
+    bool qml = sklItem->property().toBool();
+
     if (iIndex == 0) {
-        return new SKGOperationBoardWidget(m_currentBankDocument);
+        if (qml) {
+            return new SKGOperationBoardWidgetQml(m_currentBankDocument);
+        } else {
+            return new SKGOperationBoardWidget(m_currentBankDocument);
+        }
     }
     return new SKGHtmlBoardWidget(m_currentBankDocument,
                                   getDashboardWidgetTitle(iIndex),
