@@ -23,8 +23,8 @@
 
 #include <qaction.h>
 
-#include <QDomDocument>
-#include <QKeyEvent>
+#include <qdom.h>
+#include <qevent.h>
 
 #include "skgmainpanel.h"
 #include "skgtraces.h"
@@ -246,6 +246,9 @@ void SKGPayeePluginWidget::onModifyPayee()
 
     // Display error
     SKGMainPanel::displayErrorMessage(err);
+
+    // Set focus on table
+    ui.kView->getView()->setFocus();
 }
 
 void SKGPayeePluginWidget::cleanEditor()
