@@ -52,14 +52,14 @@ public:
      * @return a string containing all information needed to set the same state.
      * Could be an XML stream
      */
-    virtual QString getState() Q_DECL_OVERRIDE;
+    virtual QString getState() override;
 
     /**
      * Set the current state
      * MUST BE OVERWRITTEN
      * @param iState must be interpreted to set the state of the widget
      */
-    virtual void setState(const QString& iState) Q_DECL_OVERRIDE;
+    virtual void setState(const QString& iState) override;
 
 private Q_SLOTS:
     void dataModified(const QString& iTableName, int iIdTransaction);
