@@ -554,7 +554,7 @@ void SKGReportPluginWidget::getWhereClauseAndTitleForItem(int row, int column, Q
         oWc += QStringLiteral(" AND ");
         oTitle += i18nc("Noun",  " and ");
     }
-    oWc += getConsolidatedWhereClause(nullptr, nullptr);
+    oWc += getConsolidatedWhereClause();
 
     QString during = ui.kPeriod->text();
 
