@@ -117,7 +117,7 @@ private Q_SLOTS:
 private:
     Q_DISABLE_COPY(SKGReportPluginWidget)
 
-    QString getConsolidatedWhereClause(QString* oWhereClausForPreviousData, QString*  oWhereClausForForecastData);
+    QString getConsolidatedWhereClause(QString* oWhereClausForPreviousData = nullptr, QString*  oWhereClausForForecastData = nullptr);
     void getWhereClauseAndTitleForItem(int row, int column, QString& oWc, QString& oTitle);
     void getWhereClauseAndTitleForSelection(QString& oWc, QString& oTitle);
     QString getWhereClauseForProperty(const QString& iProperty) const;
