@@ -112,9 +112,14 @@ QString SKGScheduledPlugin::getDashboardWidgetTitle(int iIndex)
 
 SKGBoardWidget* SKGScheduledPlugin::getDashboardWidget(int iIndex)
 {
+    // Get QML mode for dashboard
+    KConfigSkeleton* skl = SKGMainPanel::getMainPanel()->getPluginByName(QStringLiteral("Dashboard plugin"))->getPreferenceSkeleton();
+    KConfigSkeletonItem* sklItem = skl->findItem(QStringLiteral("qmlmode"));
+    bool qml = sklItem->property().toBool();
+
     return new SKGHtmlBoardWidget(m_currentBankDocument,
-                                  getDashboardWidgetTitle(iIndex),
-                                  QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/scheduled_operations.html")),
+                                  getDashboardWidgetTitle(iIndex) ,
+                                  QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/scheduled_operations.") % (qml ?  QStringLiteral("qml") :  QStringLiteral("html"))),
                                   QStringList() << QStringLiteral("v_recurrentoperation_display"));
 }
 
