@@ -52,44 +52,44 @@ public:
      * @param iArgument the arguments
      * @return true if the plugin is compatible with the document
      */
-    virtual bool setupActions(SKGDocument* iDocument, const QStringList& iArgument) Q_DECL_OVERRIDE;
+    virtual bool setupActions(SKGDocument* iDocument, const QStringList& iArgument) override;
 
     /**
      * The number of dashboard widgets of the plugin.
      * @return The number of dashboard widgets of the plugin
      */
-    virtual int getNbDashboardWidgets() Q_DECL_OVERRIDE;
+    virtual int getNbDashboardWidgets() override;
 
     /**
      * Get a dashboard widget title of the plugin.
      * @param iIndex the index of the widget
      * @return The title
      */
-    virtual QString getDashboardWidgetTitle(int iIndex) Q_DECL_OVERRIDE;
+    virtual QString getDashboardWidgetTitle(int iIndex) override;
 
     /**
      * Get a dashboard widget of the plugin.
      * @param iIndex the index of the widget
      * @return The dashboard widget of the plugin
      */
-    virtual SKGBoardWidget* getDashboardWidget(int iIndex) Q_DECL_OVERRIDE;
+    virtual SKGBoardWidget* getDashboardWidget(int iIndex) override;
 
     /**
      * Must be modified to refresh widgets after a modification.
      */
-    virtual void refresh() Q_DECL_OVERRIDE;
+    virtual void refresh() override;
 
     /**
     * The preference widget of the plugin.
     * @return The preference widget of the plugin
      */
-    virtual QWidget* getPreferenceWidget() Q_DECL_OVERRIDE;
+    virtual QWidget* getPreferenceWidget() override;
 
     /**
      * The preference skeleton of the plugin.
      * @return The preference skeleton of the plugin
      */
-    virtual KConfigSkeleton* getPreferenceSkeleton() Q_DECL_OVERRIDE;
+    virtual KConfigSkeleton* getPreferenceSkeleton() override;
 
     /**
      * This function is called when preferences have been modified. Must be used to save some parameters into the document.
@@ -97,55 +97,55 @@ public:
      * @return an object managing the error.
      *   @see SKGError
      */
-    virtual SKGError savePreferences() const Q_DECL_OVERRIDE;
+    virtual SKGError savePreferences() const override;
 
     /**
      * The page widget of the plugin.
      * @return The page widget of the plugin
      */
-    virtual SKGTabPage* getWidget() Q_DECL_OVERRIDE;
+    virtual SKGTabPage* getWidget() override;
 
     /**
      * The title of the plugin.
      * @return The title of the plugin
      */
-    virtual QString title() const Q_DECL_OVERRIDE;
+    virtual QString title() const override;
 
     /**
      * The icon of the plugin.
      * @return The icon of the plugin
      */
-    virtual QString icon() const Q_DECL_OVERRIDE;
+    virtual QString icon() const override;
 
     /**
      * The toolTip of the plugin.
      * @return The toolTip of the plugin
      */
-    virtual QString toolTip() const Q_DECL_OVERRIDE;
+    virtual QString toolTip() const override;
 
     /**
      * The tips list of the plugin.
      * @return The tips list of the plugin
      */
-    virtual QStringList tips() const Q_DECL_OVERRIDE;
+    virtual QStringList tips() const override;
 
     /**
      * Must be implemented to set the position of the plugin.
      * @return integer value between 0 and 999 (default = 999)
      */
-    virtual int getOrder() const Q_DECL_OVERRIDE;
+    virtual int getOrder() const override;
 
     /**
      * Must be implemented to know if a plugin must be display in pages chooser.
      * @return true of false (default = false)
      */
-    virtual bool isInPagesChooser() const Q_DECL_OVERRIDE;
+    virtual bool isInPagesChooser() const override;
 
     /**
      * The advice list of the plugin.
      * @return The advice list of the plugin
      */
-    virtual SKGAdviceList advice(const QStringList& iIgnoredAdvice) Q_DECL_OVERRIDE;
+    virtual SKGAdviceList advice(const QStringList& iIgnoredAdvice) override;
 
     /**
      * Must be implemented to execute the automatic correction for the advice.
@@ -154,7 +154,7 @@ public:
      * @return an object managing the error. MUST return ERR_NOTIMPL if iAdviceIdentifier is not known
      *   @see SKGError
      */
-    virtual SKGError executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution) Q_DECL_OVERRIDE;
+    virtual SKGError executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution) override;
 
 private Q_SLOTS:
     void onScheduleOperation();
