@@ -23,7 +23,7 @@
 
 #include <qaction.h>
 
-#include <QDomDocument>
+#include <qdom.h>
 
 #include "skgdocumentbank.h"
 #include "skgtraces.h"
@@ -49,7 +49,7 @@ SKGAlarmBoardWidget::SKGAlarmBoardWidget(SKGDocument* iDocument)
     // Create menu
     setContextMenuPolicy(Qt::ActionsContextMenu);
 
-    QAction* open = new QAction(SKGServices::fromTheme(QStringLiteral("quickopen")), i18nc("Verb, open a page", "Open..."), this);
+    auto open = new QAction(SKGServices::fromTheme(QStringLiteral("quickopen")), i18nc("Verb, open a page", "Open..."), this);
     open->setData(QStringLiteral("skg://skrooge_search_plugin"));
     connect(open, &QAction::triggered, SKGMainPanel::getMainPanel(), [ = ]() {
         SKGMainPanel::getMainPanel()->SKGMainPanel::openPage();
@@ -72,7 +72,7 @@ SKGAlarmBoardWidget::~SKGAlarmBoardWidget()
 {
     SKGTRACEINFUNC(10);
 
-    m_menuFavorite = NULL;
+    m_menuFavorite = nullptr;
 }
 
 QString SKGAlarmBoardWidget::getState()
@@ -135,7 +135,7 @@ void SKGAlarmBoardWidget::dataModified(const QString& iTableName, int iIdTransac
                     SKGRuleObject::SKGAlarmInfo alarm = rule.getAlarmInfo();
 
                     // Create progress bar
-                    SKGProgressBar* progressBar = new SKGProgressBar(m_frame);
+                    auto progressBar = new SKGProgressBar(m_frame);
                     progressBar->setObjectName(QStringLiteral("progressBar"));
                     progressBar->setMaximum(qMax(alarm.Amount, alarm.Limit));
                     progressBar->setValue(alarm.Amount);
@@ -162,7 +162,7 @@ void SKGAlarmBoardWidget::dataModified(const QString& iTableName, int iIdTransac
                     m_layout->addWidget(progressBar);
                 }
             } else {
-                QLabel* lab = new QLabel(m_frame);
+                auto lab = new QLabel(m_frame);
                 lab->setTextInteractionFlags(Qt::LinksAccessibleByMouse | Qt::TextSelectableByMouse);
                 lab->setText(i18nc("Message", "No alarm defined<br>on the <a href=\"%1\">\"Search and process\"</a> page.", "skg://Skrooge_search_plugin"));
                 connect(lab, &QLabel::linkActivated, [ = ](const QString & val) {
