@@ -21,9 +21,9 @@
  */
 #include "skgsearchpluginwidget.h"
 
-#include <QDomDocument>
+#include <qdom.h>
 #include <qdir.h>
-#include <QKeyEvent>
+#include <qevent.h>
 
 #include "skgobjectmodel.h"
 #include "skgmainpanel.h"
@@ -119,7 +119,7 @@ SKGSearchPluginWidget::SKGSearchPluginWidget(SKGDocument* iDocument)
 
     // Add registered global action in contextual menu
     if (SKGMainPanel::getMainPanel()) {
-        QMenu* menu = new QMenu(this);
+        auto menu = new QMenu(this);
         menu->setIcon(SKGServices::fromTheme(QStringLiteral("system-run")));
         menu->addAction(SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("execute_all")));
         menu->addAction(SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("execute_imported")));
@@ -212,7 +212,7 @@ SKGObjectBase::SKGListSKGObjectBase SKGSearchPluginWidget::getSelectedObjects()
 {
     SKGObjectBase::SKGListSKGObjectBase list = ui.kView->getView()->getSelectedObjects();
 
-    // Sort selection by f_sortorder. It's mandatory for reorder functions
+    // Sort selection by f_sortorder. It is mandatory for reorder functions
     qStableSort(list.begin(), list.end());
 
     return list;
@@ -327,6 +327,9 @@ void SKGSearchPluginWidget::onModifyRule()
 
     // Display error
     SKGMainPanel::displayErrorMessage(err);
+
+    // Set focus on table
+    ui.kView->getView()->setFocus();
 }
 
 void SKGSearchPluginWidget::onSelectionChanged()
