@@ -230,7 +230,8 @@ void SKGUnitBoardWidget::dataModified(const QString& iTableName, int iIdTransact
                         }
                         html += doc->formatMoney(SKGServices::stringToDouble(obj.getAttribute(QStringLiteral("f_CURRENTAMOUNT"))), primary);
                         html += QStringLiteral("</td><td>(");
-                        double val = obj.getDailyChange();
+                        double amountOneYearBefore = obj.getAmount(QDate::currentDate().addYears(-1));
+                        double val = 100.0 * (obj.getAmount() - amountOneYearBefore) / amountOneYearBefore;
                         html += doc->formatPercentage(val);
                         html += QStringLiteral(")</td></tr>");
                     }
