@@ -103,9 +103,14 @@ SKGBoardWidget* SKGUnitPlugin::getDashboardWidget(int iIndex)
     if (iIndex == 0) {
         return new SKGUnitBoardWidget(m_currentBankDocument);
     } else {
+        // Get QML mode for dashboard
+        KConfigSkeleton* skl = SKGMainPanel::getMainPanel()->getPluginByName(QStringLiteral("Dashboard plugin"))->getPreferenceSkeleton();
+        KConfigSkeletonItem* sklItem = skl->findItem(QStringLiteral("qmlmode"));
+        bool qml = sklItem->property().toBool();
+
         return new SKGHtmlBoardWidget(m_currentBankDocument,
                                       getDashboardWidgetTitle(iIndex),
-                                      QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/portfolio.html")),
+                                      QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/portfolio.") % (qml ?  QStringLiteral("qml") :  QStringLiteral("html"))),
                                       QStringList() << QStringLiteral("v_operation_display"));
     }
 }
