@@ -455,7 +455,8 @@ QVariant SKGObjectModel::computeData(const QModelIndex& iIndex, int iRole) const
         } else if (m_unitTable) {
             if (att == QStringLiteral("f_CURRENTAMOUNT")) {
                 SKGUnitObject unit(*obj);
-                double annualchange = 365 * unit.getDailyChange();
+                double amountOneYearBefore = unit.getAmount(QDate::currentDate().addYears(-1));
+                double annualchange = 100.0 * (unit.getAmount() - amountOneYearBefore) / amountOneYearBefore;
                 if (annualchange >= 15) {
                     return m_iconMuchMore;
                 } else if (annualchange <= -15) {
@@ -715,6 +716,18 @@ QVariant SKGObjectModel::computeData(const QModelIndex& iIndex, int iRole) const
                                            SKGServices::toCurrencyString(val, primaryUnit.Symbol, primaryUnit.NbDecimal));
                 }
             }
+
+            if (m_unitTable) {
+                if (att == QStringLiteral("f_CURRENTAMOUNT")) {
+                    SKGUnitObject unit(*obj);
+                    double amountOneYearBefore = unit.getAmount(QDate::currentDate().addYears(-1));
+                    double annualchange = 100.0 * (unit.getAmount() - amountOneYearBefore) / amountOneYearBefore;
+                    if (!toolTipString.isEmpty()) {
+                        toolTipString += QStringLiteral("\n\n");
+                    }
+                    toolTipString += SKGServices::toPercentageString(annualchange);
+                }
+            }
         } else if (m_operationTable || m_recurrentoperationTable) {
             if (att == QStringLiteral("t_imported")) {
                 SKGOperationObject op(*obj);
@@ -741,7 +754,7 @@ QVariant SKGObjectModel::computeData(const QModelIndex& iIndex, int iRole) const
                 if (SKGServices::stringToInt(op.getAttribute(QStringLiteral("i_NBSUBOPERATIONS"))) > 1) {
                     SKGObjectBase::SKGListSKGObjectBase subOps;
                     op.getSubOperations(subOps);
-                    for (const auto& subOp : subOps) {
+                    for (const auto& subOp : qAsConst(subOps)) {
                         toolTipString += subOp.getDisplayName() % '\n';
                     }
                 }
@@ -757,7 +770,7 @@ QVariant SKGObjectModel::computeData(const QModelIndex& iIndex, int iRole) const
 
                     SKGObjectBase::SKGListSKGObjectBase gOps;
                     op.getGroupedOperations(gOps);
-                    for (const auto& item : gOps) {
+                    for (const auto& item : qAsConst(gOps)) {
                         SKGOperationObject gOp(item);
                         SKGAccountObject account;
                         gOp.getParentAccount(account);
