@@ -32,6 +32,8 @@
 #include "skgdocumentbank.h"
 #include "skgtraces.h"
 
+SKGAccountObject::SKGAccountObject() : SKGAccountObject(nullptr, 0) {}
+
 SKGAccountObject::SKGAccountObject(SKGDocument* iDocument, int iID) : SKGNamedObject(iDocument, QStringLiteral("v_account"), iID) {}
 
 SKGAccountObject::~SKGAccountObject() {}
@@ -777,11 +779,10 @@ SKGError SKGAccountObject::transferDeferredOperations(const SKGAccountObject& iT
     return err;
 }
 
-SKGError SKGAccountObject::autoReconcile(double iBalance)
+QVector< SKGObjectBase::SKGListSKGObjectBase > SKGAccountObject::getPossibleReconciliations(double iTargetBalance) const
 {
-    SKGError err;
-    SKGTRACEINFUNCRC(10, err);
-    //
+    SKGTRACEINFUNC(10);
+    QVector< SKGObjectBase::SKGListSKGObjectBase > output;
     SKGDocumentBank* doc = qobject_cast<SKGDocumentBank*>(getDocument());
     if (doc) {
         // Get unit
@@ -795,58 +796,164 @@ SKGError SKGAccountObject::autoReconcile(double iBalance)
         }
 
         // Get balance of checked operations
-        double balance = 0;
-        SKGStringListList listTmp2;
-        err = getDocument()->executeSelectSqliteOrder(
-                  "SELECT TOTAL(f_CHECKED) from v_account_display WHERE id=" % SKGServices::intToString(getID()),
-                  listTmp2);
-        if (listTmp2.count() == 2) {
-            balance = SKGServices::stringToDouble(listTmp2.at(1).at(0)) / unit1.Value;
-        }
-
+        QString balanceString;
+        getDocument()->executeSingleSelectSqliteOrder("SELECT f_CHECKED from v_account_display WHERE id=" % SKGServices::intToString(getID()), balanceString);
+        double balance = SKGServices::stringToDouble(balanceString);
 
         // Get all imported operation
-        double diff = balance - iBalance;
         SKGObjectBase::SKGListSKGObjectBase operations;
-        IFOKDO(err, getDocument()->getObjects(QStringLiteral("v_operation"), "rd_account_id=" % SKGServices::intToString(getID()) % " AND t_status='N' AND t_template='N' AND t_imported IN ('Y','P') ORDER BY d_date, id", operations))
-
+        getDocument()->getObjects(QStringLiteral("v_operation"), "rd_account_id=" % SKGServices::intToString(getID()) % " AND t_status='N' AND t_template='N' AND t_imported IN ('Y','P') ORDER BY d_date, id", operations);
 
         // Comparison
-        QString zero = doc->formatMoney(0, unit1);
-        QString negativezero = doc->formatMoney(-EPSILON, unit1);
+        output = getPossibleReconciliations(operations, balance, iTargetBalance, unit1);
 
-        // Try to find the soluce
-        int nb = operations.count();
+        QString zero = doc->formatMoney(0, unit1, false);
+        QString negativezero = doc->formatMoney(-EPSILON, unit1, false);
 
-        QString sdiff = doc->formatMoney(diff, unit1);
-        int limit = -1;
-        bool moreThanOneSoluceFound = false;
-        for (int i = 0; !moreThanOneSoluceFound && !err && i < nb; ++i) {
-            SKGOperationObject op(operations.at(i));
-            double amount = op.getCurrentAmount();
-            diff += amount;
-            sdiff = doc->formatMoney(diff, unit1);
-            SKGTRACEL(5) << (i + 1) << "/" << nb << ": Amount=" << amount << " / New diff=" << sdiff << endl;
-            if (sdiff == zero || sdiff == negativezero) {
-                if (limit != -1) {
-                    err = getDocument()->sendMessage(i18nc("An information message",  "More than one solution is possible for this auto reconciliation."));
-                    moreThanOneSoluceFound = true;
+        QString sdiff = doc->formatMoney(balance - iTargetBalance * unit1.Value, unit1, false);
+        if (sdiff == zero || sdiff == negativezero) {
+            // This is an empty soluce
+            output.push_back(SKGObjectBase::SKGListSKGObjectBase());
+            SKGTRACEL(5) << "empty solution found !!!" << endl;
+        }
+    }
+    return output;
+}
+
+QVector< SKGObjectBase::SKGListSKGObjectBase > SKGAccountObject::getPossibleReconciliations(const SKGObjectBase::SKGListSKGObjectBase& iOperations, double iBalance, double iTargetBalance, const SKGServices::SKGUnitInfo& iUnit) const
+{
+    SKGTRACEINFUNC(5);
+    QVector< SKGObjectBase::SKGListSKGObjectBase > output;
+    output.reserve(5);
+    SKGDocumentBank* doc = qobject_cast<SKGDocumentBank*>(getDocument());
+    if (doc) {
+        // Comparison
+        QString zero = doc->formatMoney(0, iUnit, false);
+        QString negativezero = doc->formatMoney(-EPSILON, iUnit, false);
+
+        // Check operations list
+        int nb = iOperations.count();
+        if (nb > 0) {
+            // Get all operations of the next date
+            SKGObjectBase::SKGListSKGObjectBase nextOperation;
+            nextOperation.reserve(iOperations.count());
+            QString date = iOperations.at(0).getAttribute(QStringLiteral("d_date"));
+            for (int i = 0; i < nb; ++i) {
+                SKGObjectBase op = iOperations.at(i);
+                if (op.getAttribute(QStringLiteral("d_date")) == date) {
+                    nextOperation.push_back(op);
                 } else {
-                    limit = i;
+                    break;
                 }
             }
+
+            // Get all combination of operations
+            int nbNext = nextOperation.count();
+            SKGTRACEL(10) << date << ":" << nbNext << " operations found" << endl;
+            std::vector<int> v(nbNext);
+            for (int i = 0; i < nbNext; ++i) {
+                v[i] = i;
+            }
+
+            QVector<SKGObjectBase::SKGListSKGObjectBase> nextOperationCombinations;
+            do {
+                SKGObjectBase::SKGListSKGObjectBase combi;
+                combi.reserve(nbNext);
+                for (int i = 0; i < nbNext; ++i) {
+                    combi.push_back(nextOperation.at(v[i]));
+                }
+                nextOperationCombinations.push_back(combi);
+            } while (std::next_permutation(v.begin(), v.end()));
+
+            // Test each combination
+            nb = nextOperationCombinations.count();
+            double nextBalance = iBalance;
+            for (int i = 0; i < nb; ++i) {
+                SKGTRACEL(5) << "Check combination " << (i + 1) << "/" << nb << endl;
+                double diff = iBalance - iTargetBalance * iUnit.Value;
+                auto operations = nextOperationCombinations.at(i);
+
+                // Try to find an immediate soluce
+                int nbop = operations.count();
+                for (int j = 0; j < nbop; ++j) {
+                    SKGOperationObject op(operations.at(j));
+                    double amount = op.getCurrentAmount();
+                    diff += amount;
+                    if (i == 0) {
+                        nextBalance += amount;
+                    }
+                    QString sdiff = doc->formatMoney(diff, iUnit, false);
+                    SKGTRACEL(5) << (j + 1) << "/" << nbop << ": Amount=" << amount << " / New diff=" << sdiff << endl;
+                    if (sdiff == zero || sdiff == negativezero) {
+                        // This is a soluce
+                        auto s = operations.mid(0, j + 1);
+                        if (output.contains(s)) {
+                            SKGTRACEL(5) << "found but already existing !!!" << endl;
+                        } else {
+                            output.push_back(s);
+                            SKGTRACEL(5) << "found !!!" << endl;
+                            if (j == nbop - 1) {
+                                // No need to test all combinations
+                                i = nb - 1;
+                            }
+                        }
+                    }
+                }
+            }
+
+            // Try to find next solutions
+            auto reconciliations = getPossibleReconciliations(iOperations.mid(nbNext), nextBalance, iTargetBalance, iUnit);
+            int nbReconciliations = reconciliations.count();
+            output.reserve(nbReconciliations + 5);
+            for (int i = 0; i < nbReconciliations; ++i) {
+                SKGObjectBase::SKGListSKGObjectBase output2 = nextOperation;
+                output2 = output2 << reconciliations.at(i);
+                output.push_back(output2);
+            }
+        }
+    }
+
+    SKGTRACEL(5) << output.count() << " soluces found" << endl;
+    if (!output.isEmpty()) {
+        SKGTRACEL(5) << "Size of the first soluce: " << output.at(0).count() << endl;
+    }
+    return output;
+}
+
+SKGError SKGAccountObject::autoReconcile(double iBalance)
+{
+    SKGError err;
+    SKGTRACEINFUNCRC(5, err);
+
+    // Soluces
+    auto soluces = getPossibleReconciliations(iBalance);
+    int nbSoluces = soluces.count();
+    if (nbSoluces > 0) {
+        if (nbSoluces > 1) {
+            err = getDocument()->sendMessage(i18nc("An information message",  "More than one solution is possible for this auto reconciliation."));
+        }
+
+        // Choose the longest solution
+        SKGObjectBase::SKGListSKGObjectBase soluce;
+        int length = 0;
+        for (int i = 0; i < nbSoluces; ++i) {
+            SKGObjectBase::SKGListSKGObjectBase s = soluces.at(i);
+            int l = s.count();
+            if (l > length) {
+                soluce = s;
+                length = l;
+            }
         }
 
         // Check all
-        if (limit != -1) {
-            for (int i = 0; !err && i <= limit; ++i) {
-                SKGOperationObject op(operations.at(i));
-                err = op.setStatus(SKGOperationObject::POINTED);
-                IFOKDO(err, op.save(true, false))
-            }
-        } else {
-            err = SKGError(ERR_FAIL, i18nc("Error message",  "Can not find the imported operations for obtaining the expected final balance"));
+        SKGTRACEL(5) << length << " operations pointed" << endl;
+        for (int i = 0; i < length; ++i) {
+            SKGOperationObject op(soluce.at(i));
+            err = op.setStatus(SKGOperationObject::POINTED);
+            IFOKDO(err, op.save(true, false))
         }
+    } else {
+        err = SKGError(ERR_FAIL, i18nc("Error message",  "Can not find the imported operations for obtaining the expected final balance"));
     }
 
     return err;
