@@ -25,6 +25,7 @@
 
 #include "skgdocumentbank.h"
 #include "skgtraces.h"
+#include "skgdefine.h"
 #include "skgcategoryobject.h"
 #include "skgbudgetruleobject.h"
 #include "skgtransactionmng.h"
@@ -340,7 +341,7 @@ SKGError SKGBudgetObject::balanceBudget(SKGDocumentBank* iDocument, int iYear, i
 
         // Monthly balancing
         if (!err && iMonth != -1) {
-            for (int m = (iMonth == 0 ? 1 : iMonth); !err && m <= (iMonth == 0 ? 12 : iMonth); ++m) {
+            for (int m = (iMonth == 0 ? 1 : qAsConst(iMonth)); !err && m <= (iMonth == 0 ? 12 : iMonth); ++m) {
                 SKGStringListList listTmp;
                 err = iDocument->executeSelectSqliteOrder("SELECT TOTAL(f_budgeted) FROM budget WHERE i_year=" % SKGServices::intToString(iYear) % " AND i_month=" % SKGServices::intToString(m) % " AND rc_category_id<>0", listTmp);
                 if (!err && listTmp.count() == 2) {
