@@ -32,7 +32,7 @@ class SKGDocumentBank;
 /**
  * This class is a budget
  */
-class SKGBANKMODELER_EXPORT SKGBudgetObject : public SKGObjectBase
+class SKGBANKMODELER_EXPORT SKGBudgetObject final : public SKGObjectBase
 {
     Q_OBJECT
 public:
@@ -51,7 +51,7 @@ public:
     /**
      * Destructor
      */
-    virtual ~SKGBudgetObject();
+    ~SKGBudgetObject();
 
     /**
      * Copy constructor
@@ -69,7 +69,7 @@ public:
      * Operator affectation
      * @param iObject the object to copy
      */
-    virtual const SKGBudgetObject& operator= (const SKGObjectBase& iObject) override;
+    const SKGBudgetObject& operator= (const SKGObjectBase& iObject) override;
 
     /**
      * Set year of the budget
@@ -77,13 +77,13 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError setYear(int iYear);
+    SKGError setYear(int iYear);
 
     /**
      * Get year of the budget
      * @return year of the budget
      */
-    virtual int getYear() const;
+    int getYear() const;
 
     /**
      * Set month of the budget
@@ -91,13 +91,13 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError setMonth(int iMonth);
+    SKGError setMonth(int iMonth);
 
     /**
      * Get month of the budget
      * @return month of the budget
      */
-    virtual int getMonth() const;
+    int getMonth() const;
 
     /**
      * Set the category
@@ -105,14 +105,14 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError setCategory(const SKGCategoryObject& iCategory);
+    SKGError setCategory(const SKGCategoryObject& iCategory);
 
     /**
      * Remove the category
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError removeCategory();
+    SKGError removeCategory();
 
     /**
      * Get the category
@@ -120,7 +120,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError getCategory(SKGCategoryObject& oCategory) const;
+    SKGError getCategory(SKGCategoryObject& oCategory) const;
 
     /**
      * Enable / disable the inclusion of sub categories
@@ -128,13 +128,13 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError enableSubCategoriesInclusion(bool iEnable);
+    SKGError enableSubCategoriesInclusion(bool iEnable);
 
     /**
      * To know if sub categories inclusion is enabled or disabled
      * @return condition
      */
-    virtual int isSubCategoriesInclusionEnabled() const;
+    int isSubCategoriesInclusionEnabled() const;
 
     /**
      * Set budgeted amount of the budget
@@ -142,32 +142,32 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError setBudgetedAmount(double iAmount);
+    SKGError setBudgetedAmount(double iAmount);
 
     /**
      * Get budgeted amount of the budget
      * @return budgeted amount of the budget
      */
-    virtual double getBudgetedAmount() const;
+    double getBudgetedAmount() const;
 
     /**
      * Get budgeted modified amount of the budget
      * @return budgeted modified amount of the budget
      */
-    virtual double getBudgetedModifiedAmount() const;
+    double getBudgetedModifiedAmount() const;
 
     /**
      * Get delta
      * @return delta
      */
-    virtual double getDelta() const;
+    double getDelta() const;
 
     /**
      * Process all rules
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError process();
+    SKGError process();
 
     /**
      * Create automatically budget items based on existing operations
@@ -193,7 +193,7 @@ public:
     static SKGError balanceBudget(SKGDocumentBank* iDocument, int iYear, int iMonth = 0, bool iBalanceYear = true);
 
 private:
-    virtual QString getWhereclauseId() const override;
+    QString getWhereclauseId() const override;
 };
 /**
  * Declare the class
