@@ -29,19 +29,20 @@
 #include "skgcategoryobject.h"
 #include "skgtransactionmng.h"
 
+SKGBudgetRuleObject::SKGBudgetRuleObject()
+    : SKGBudgetRuleObject(nullptr)
+{}
+
 SKGBudgetRuleObject::SKGBudgetRuleObject(SKGDocument* iDocument, int iID)
     : SKGObjectBase(iDocument, QStringLiteral("v_budgetrule"), iID)
-{
-}
+{}
 
 SKGBudgetRuleObject::~SKGBudgetRuleObject()
-{
-}
+{}
 
 SKGBudgetRuleObject::SKGBudgetRuleObject(const SKGBudgetRuleObject& iObject)
     : SKGObjectBase(iObject)
-{
-}
+{}
 
 SKGBudgetRuleObject::SKGBudgetRuleObject(const SKGObjectBase& iObject)
 {
