@@ -32,7 +32,7 @@ class SKGDocumentBank;
 /**
  * This class is a budget rule
  */
-class SKGBANKMODELER_EXPORT SKGBudgetRuleObject : public SKGObjectBase
+class SKGBANKMODELER_EXPORT SKGBudgetRuleObject final : public SKGObjectBase
 {
     Q_OBJECT
 public:
@@ -75,7 +75,7 @@ public:
     /**
      * Destructor
      */
-    virtual ~SKGBudgetRuleObject();
+    ~SKGBudgetRuleObject();
 
     /**
      * Copy constructor
@@ -93,7 +93,7 @@ public:
      * Operator affectation
      * @param iObject the object to copy
      */
-    virtual const SKGBudgetRuleObject& operator= (const SKGObjectBase& iObject) override;
+    const SKGBudgetRuleObject& operator= (const SKGObjectBase& iObject) override;
 
     /**
      * Enable / disable condition on year of the budget
@@ -101,13 +101,13 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError enableYearCondition(bool iEnable);
+    SKGError enableYearCondition(bool iEnable);
 
     /**
      * To know if condition on year is enabled or disabled
      * @return condition
      */
-    virtual int isYearConditionEnabled() const;
+    int isYearConditionEnabled() const;
 
     /**
      * Set year of the condition of the rule
@@ -115,13 +115,13 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError setBudgetYear(int iYear);
+    SKGError setBudgetYear(int iYear);
 
     /**
      * Get year of the condition of the rule
      * @return year of the condition of the rule
      */
-    virtual int getBudgetYear() const;
+    int getBudgetYear() const;
 
     /**
      * Enable / disable condition on month of the budget
@@ -129,13 +129,13 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError enableMonthCondition(bool iEnable);
+    SKGError enableMonthCondition(bool iEnable);
 
     /**
      * To know if condition on month is enabled or disabled
      * @return condition
      */
-    virtual int isMonthConditionEnabled() const;
+    int isMonthConditionEnabled() const;
 
     /**
      * Set month of the condition of the rule
@@ -143,13 +143,13 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError setBudgetMonth(int iMonth);
+    SKGError setBudgetMonth(int iMonth);
 
     /**
      * Get month of the condition of the rule
      * @return month of the budget
      */
-    virtual int getBudgetMonth() const;
+    int getBudgetMonth() const;
 
     /**
      * Enable / disable condition on category of the budget
@@ -157,13 +157,13 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError enableCategoryCondition(bool iEnable);
+    SKGError enableCategoryCondition(bool iEnable);
 
     /**
      * To know if condition on category is enabled or disabled
      * @return condition
      */
-    virtual int isCategoryConditionEnabled() const;
+    int isCategoryConditionEnabled() const;
 
     /**
      * Set the category of the condition of the rule
@@ -171,14 +171,14 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError setBudgetCategory(const SKGCategoryObject& iCategory);
+    SKGError setBudgetCategory(const SKGCategoryObject& iCategory);
 
     /**
      * Remove the category of the condition of the rule
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError removeBudgetCategory();
+    SKGError removeBudgetCategory();
 
     /**
      * Get the category of the condition of the rule
@@ -186,7 +186,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError getBudgetCategory(SKGCategoryObject& oCategory) const;
+    SKGError getBudgetCategory(SKGCategoryObject& oCategory) const;
 
     /**
      * Set the condition when the rule must be applied
@@ -194,13 +194,13 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError setCondition(SKGBudgetRuleObject::Condition iCondition);
+    SKGError setCondition(SKGBudgetRuleObject::Condition iCondition);
 
     /**
      * Get the condition when the rule must be applied
      * @return the condition
      */
-    virtual SKGBudgetRuleObject::Condition getCondition() const;
+    SKGBudgetRuleObject::Condition getCondition() const;
 
     /**
      * Set the quantity to transfer
@@ -209,19 +209,19 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError setQuantity(double iQuantity, bool iAbsolute);
+    SKGError setQuantity(double iQuantity, bool iAbsolute);
 
     /**
      * Get quantity to transfer
      * @return quantity to transfer
      */
-    virtual double getQuantity() const;
+    double getQuantity() const;
 
     /**
      * To know if the quantity is an amount or a percentage
      * @return true means "an amount in primary unit", false means "a percentage"
      */
-    virtual bool isAbolute() const;
+    bool isAbolute() const;
 
     /**
      * Enable / disable transfer change the category of the budget
@@ -229,13 +229,13 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError enableCategoryChange(bool iEnable);
+    SKGError enableCategoryChange(bool iEnable);
 
     /**
      * To know if transfer change the category
      * @return transfer change the category
      */
-    virtual int isCategoryChangeEnabled() const;
+    int isCategoryChangeEnabled() const;
 
     /**
      * Set the transfer to apply
@@ -244,13 +244,13 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError setTransfer(SKGBudgetRuleObject::Mode iMode, const SKGCategoryObject& iCategory = SKGCategoryObject());
+    SKGError setTransfer(SKGBudgetRuleObject::Mode iMode, const SKGCategoryObject& iCategory = SKGCategoryObject());
 
     /**
      * Get the mode of the transfer
      * @return the mode
      */
-    virtual SKGBudgetRuleObject::Mode getTransferMode() const;
+    SKGBudgetRuleObject::Mode getTransferMode() const;
 
     /**
      * Get the category of the transfer of the rule
@@ -258,7 +258,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError getTransferCategory(SKGCategoryObject& oCategory) const;
+    SKGError getTransferCategory(SKGCategoryObject& oCategory) const;
 
     /**
      * Process all rules
