@@ -27,18 +27,17 @@
 #include "skgdocumentbank.h"
 #include "skgtraces.h"
 
+SKGCategoryObject::SKGCategoryObject() : SKGCategoryObject(nullptr)
+{}
+
 SKGCategoryObject::SKGCategoryObject(SKGDocument* iDocument, int iID) : SKGNamedObject(iDocument, QStringLiteral("v_category"), iID)
-{
-}
+{}
 
 SKGCategoryObject::~SKGCategoryObject()
-{
-}
+{}
 
-SKGCategoryObject::SKGCategoryObject(const SKGCategoryObject& iObject)
-    : SKGNamedObject(iObject)
-{
-}
+SKGCategoryObject::SKGCategoryObject(const SKGCategoryObject& iObject) : SKGNamedObject(iObject)
+{}
 
 SKGCategoryObject::SKGCategoryObject(const SKGObjectBase& iObject)
 
@@ -104,7 +103,7 @@ SKGError SKGCategoryObject::createPathCategory(SKGDocumentBank* iDocument,
 
     // Check if category is already existing
     if (iFullPath.isEmpty()) {
-        oCategory = SKGCategoryObject(NULL, 0);
+        oCategory = SKGCategoryObject(nullptr, 0);
     } else if (iDocument) {
         if (!iRenameIfAlreadyExist) {
             iDocument->getObject(QStringLiteral("v_category"), "t_fullname='" % SKGServices::stringToSqlString(iFullPath) % '\'', oCategory);
@@ -188,7 +187,7 @@ SKGError SKGCategoryObject::setParentCategory(const SKGCategoryObject& iCategory
     if (iCategory.getID() == 0) {
         err = SKGError(ERR_FAIL,  i18nc("Error message", "%1 failed because linked object is not yet saved in the database." , QStringLiteral("SKGCategoryObject::setParentCategory")));
     } else {
-        // Check if it's a loop
+        // Check if it is a loop
         SKGCategoryObject current = iCategory;
         do {
             if (current == *this) {
