@@ -538,7 +538,7 @@ SKGError SKGOperationObject::mergeAttribute(const SKGOperationObject& iDeletedOn
             IFOKDO(err, so1.save())
         } else {
             // Keep ratio
-            for (const auto& sopbase : subOps1) {
+            for (const auto& sopbase : qAsConst(subOps1)) {
                 SKGSubOperationObject sop(sopbase);
                 IFOKDO(err, sop.setQuantity(targettAmount * sop.getQuantity() / currentAmount))
                 IFOKDO(err, sop.save())
