@@ -29,18 +29,17 @@
 #include "skgdocumentbank.h"
 #include "skgtraces.h"
 
+SKGRecurrentOperationObject::SKGRecurrentOperationObject(): SKGRecurrentOperationObject(nullptr)
+{}
+
 SKGRecurrentOperationObject::SKGRecurrentOperationObject(SKGDocument* iDocument, int iID): SKGObjectBase(iDocument, QStringLiteral("v_recurrentoperation"), iID)
-{
-}
+{}
 
 SKGRecurrentOperationObject::~SKGRecurrentOperationObject()
-{
-}
+{}
 
-SKGRecurrentOperationObject::SKGRecurrentOperationObject(const SKGRecurrentOperationObject& iObject)
-    : SKGObjectBase(iObject)
-{
-}
+SKGRecurrentOperationObject::SKGRecurrentOperationObject(const SKGRecurrentOperationObject& iObject) : SKGObjectBase(iObject)
+{}
 
 SKGRecurrentOperationObject::SKGRecurrentOperationObject(const SKGObjectBase& iObject)
 {
