@@ -29,18 +29,18 @@
 #include "skgservices.h"
 #include "skgdocument.h"
 
+SKGSubOperationObject::SKGSubOperationObject(): SKGSubOperationObject(nullptr)
+{}
+
 SKGSubOperationObject::SKGSubOperationObject(SKGDocument* iDocument, int iID): SKGObjectBase(iDocument, QStringLiteral("v_suboperation"), iID)
-{
-}
+{}
 
 SKGSubOperationObject::~SKGSubOperationObject()
-{
-}
+{}
 
 SKGSubOperationObject::SKGSubOperationObject(const SKGSubOperationObject& iObject)
     : SKGObjectBase(iObject)
-{
-}
+{}
 
 SKGSubOperationObject::SKGSubOperationObject(const SKGObjectBase& iObject)
 {
