@@ -673,7 +673,8 @@ QStringList SKGUnitObject::downloadSources()
 {
     QStringList sources;
     QString a = QStringLiteral("skrooge/quotes");
-    for (const auto& dir : QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, a, QStandardPaths::LocateDirectory)) {
+    const auto list = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, a, QStandardPaths::LocateDirectory);
+    for (const auto& dir : list) {
         QDirIterator it(dir, QStringList() << QStringLiteral("*.txt"));
         while (it.hasNext()) {
             QFileInfo f(it.next());
@@ -1068,7 +1069,7 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
                     unitYahooCode.push_back("w4");
                     unitYahooTitle.push_back(i18nc("Yahoo title for a downloaded information of a share", "Day's Value Change (RT)"));*/
 
-                    for (const auto& key : unitYahooCode) {
+                    for (const auto& key : qAsConst(unitYahooCode)) {
                         yahooString += key;
                     }
 
