@@ -34,7 +34,7 @@ class SKGDocumentBank;
 /**
  * This class is a unit
  */
-class SKGBANKMODELER_EXPORT SKGUnitObject : public SKGNamedObject
+class SKGBANKMODELER_EXPORT SKGUnitObject final : public SKGNamedObject
 {
     Q_OBJECT
     /**
@@ -78,7 +78,7 @@ public:
     /**
      * Destructor
      */
-    virtual ~SKGUnitObject();
+    ~SKGUnitObject();
 
     /**
      * Copy constructor
@@ -103,14 +103,14 @@ public:
      * Operator affectation
      * @param iObject the object to copy
      */
-    virtual const SKGUnitObject& operator= (const SKGObjectBase& iObject) override;
+    const SKGUnitObject& operator= (const SKGObjectBase& iObject) override;
 
     /**
      * Get unit information
      * @return the unit information
      *   @see SKGUnitInfo
      */
-    virtual SKGServices::SKGUnitInfo getUnitInfo();
+    SKGServices::SKGUnitInfo getUnitInfo();
 
     /**
      * Get unit information
@@ -161,13 +161,13 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError setSymbol(const QString& iSymbol);
+    SKGError setSymbol(const QString& iSymbol);
 
     /**
      * Get the symbol of this unit
      * @return the symbol
      */
-    virtual QString getSymbol() const;
+    QString getSymbol() const;
 
     /**
      * Set the download source of this unit
@@ -175,13 +175,13 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError setDownloadSource(const QString& iSource);
+    SKGError setDownloadSource(const QString& iSource);
 
     /**
      * Get the download source of this unit
      * @return the download source ("" means native source)
      */
-    virtual QString getDownloadSource() const;
+    QString getDownloadSource() const;
 
     /**
      * Set the number of decimal of this unit
@@ -189,13 +189,13 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError setNumberDecimal(int iNb);
+    SKGError setNumberDecimal(int iNb);
 
     /**
      * Get the number of decimal of this unit
      * @return the number of decimal
      */
-    virtual int getNumberDecimal() const;
+    int getNumberDecimal() const;
 
     /**
      * Set the country of this unit
@@ -203,13 +203,13 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError setCountry(const QString& iCountry);
+    SKGError setCountry(const QString& iCountry);
 
     /**
      * Get the country of this unit
      * @return the country
      */
-    virtual QString getCountry() const;
+    QString getCountry() const;
 
     /**
      * Set the Internet code of this unit
@@ -217,13 +217,13 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError setInternetCode(const QString& iCode);
+    SKGError setInternetCode(const QString& iCode);
 
     /**
      * Get the Internet code of this unit
      * @return the Internet code
      */
-    virtual QString getInternetCode() const;
+    QString getInternetCode() const;
 
     /**
      * Set the type of this unit
@@ -231,13 +231,13 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError setType(SKGUnitObject::UnitType iType);
+    SKGError setType(SKGUnitObject::UnitType iType);
 
     /**
      * Get the type of this unit
      * @return the type
      */
-    virtual SKGUnitObject::UnitType getType() const;
+    SKGUnitObject::UnitType getType() const;
 
     /**
      * Add a unit value
@@ -245,7 +245,7 @@ public:
      * @return an object managing the error.
      *   @see SKGError
      */
-    virtual SKGError addUnitValue(SKGUnitValueObject& oUnitValue);
+    SKGError addUnitValue(SKGUnitValueObject& oUnitValue);
 
     /**
      * Get unit values
@@ -253,7 +253,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError getUnitValues(SKGListSKGObjectBase& oUnitValueList) const;
+    SKGError getUnitValues(SKGListSKGObjectBase& oUnitValueList) const;
 
     /**
      * Get last unit value
@@ -261,7 +261,7 @@ public:
      * @return an object managing the error.
      *   @see SKGError
      */
-    virtual SKGError getLastUnitValue(SKGUnitValueObject& oUnitValue) const;
+    SKGError getLastUnitValue(SKGUnitValueObject& oUnitValue) const;
 
     /**
      * Get unit value at a date
@@ -271,7 +271,7 @@ public:
      *   @see SKGError
      */
     // cppcheck-suppress passedByValue
-    virtual SKGError getUnitValue(const QDate iDate, SKGUnitValueObject& oUnitValue) const;
+    SKGError getUnitValue(const QDate iDate, SKGUnitValueObject& oUnitValue) const;
 
     /**
      * Download values
@@ -281,7 +281,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError downloadUnitValue(UnitDownloadMode iMode = LAST, int iNbMaxValues = 50, bool iAdditionalInfo = false);
+    SKGError downloadUnitValue(UnitDownloadMode iMode = LAST, int iNbMaxValues = 50, bool iAdditionalInfo = false);
 
 
     /**
@@ -289,7 +289,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError openURL() const;
+    SKGError openURL() const;
 
     /**
      * Get the URL where the values are downloaded
@@ -297,7 +297,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError getUrl(QUrl& oUrl) const;
+    SKGError getUrl(QUrl& oUrl) const;
 
     /**
      * Get the list of sources for the download
@@ -335,7 +335,7 @@ public:
      * @return amount of the unit
      */
     // cppcheck-suppress passedByValue
-    virtual double getAmount(const QDate iDate = QDate::currentDate()) const;
+    double getAmount(const QDate iDate = QDate::currentDate()) const;
 
     /**
      * Get daily change in percentage at a date.
@@ -343,7 +343,7 @@ public:
      * @return daily change
      */
     // cppcheck-suppress passedByValue
-    virtual double getDailyChange(const QDate iDate = QDate::currentDate()) const;
+    double getDailyChange(const QDate iDate = QDate::currentDate()) const;
 
     /**
      * Set the unit
@@ -351,14 +351,14 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError setUnit(const SKGUnitObject& iUnit);
+    SKGError setUnit(const SKGUnitObject& iUnit);
 
     /**
      * Remove the unit
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError removeUnit();
+    SKGError removeUnit();
 
     /**
      * Get the unit
@@ -366,7 +366,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError getUnit(SKGUnitObject& oUnit) const;
+    SKGError getUnit(SKGUnitObject& oUnit) const;
 
     /**
      * Split unit.
@@ -376,7 +376,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError split(double iRatio) const;
+    SKGError split(double iRatio) const;
 
     /**
      * Get all operations of this unit
@@ -384,7 +384,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError getOperations(SKGListSKGObjectBase& oOperations) const;
+    SKGError getOperations(SKGListSKGObjectBase& oOperations) const;
 
     /**
      * Merge iUnit in current unit
@@ -392,7 +392,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError merge(const SKGUnitObject& iUnit);
+    SKGError merge(const SKGUnitObject& iUnit);
 
     /**
      * Remove all unit values not relevant.
@@ -400,7 +400,7 @@ public:
      * @return an object managing the error.
      *   @see SKGError
      */
-    virtual SKGError simplify();
+    SKGError simplify();
 
 protected:
     /**
@@ -408,7 +408,7 @@ protected:
      * For this class, the whereclause is based on name
      * @return the where clause
      */
-    virtual QString getWhereclauseId() const override;
+    QString getWhereclauseId() const override;
 };
 /**
  * Declare the class
