@@ -28,8 +28,6 @@
 
 #include <klocalizedstring.h>
 
-#include <QKeyEvent>
-#include <QMouseEvent>
 #include <qevent.h>
 #include <qabstractitemview.h>
 #include <qapplication.h>
@@ -75,7 +73,7 @@ KDateEdit::KDateEdit(QWidget* iParent)
     setupKeywords();
     lineEdit()->installEventFilter(this);
 
-    KDateValidator* newValidator = new KDateValidator(this);
+    auto newValidator = new KDateValidator(this);
     newValidator->setKeywords(mKeywordMap.keys());
     setValidator(newValidator);
 
@@ -355,7 +353,7 @@ void KDateEdit::setupKeywords()
         mKeywordMap.insert(dayName, i + 100);
     }
 
-    QCompleter* comp = new QCompleter(mKeywordMap.keys(), this);
+    auto comp = new QCompleter(mKeywordMap.keys(), this);
     comp->setCaseSensitivity(Qt::CaseInsensitive);
     comp->setCompletionMode(QCompleter::InlineCompletion);
     setCompleter(comp);
