@@ -21,7 +21,7 @@
 #ifndef KDEPIM_KDATEPICKERPOPUP_H
 #define KDEPIM_KDATEPICKERPOPUP_H
 
-#include <QDateTime>
+#include <qdatetime.h>
 #include <qmenu.h>
 
 class KDatePicker;
@@ -66,9 +66,9 @@ public:
        @param iParent The object's parent.
     */
     // cppcheck-suppress passedByValue
-    explicit KDatePickerPopup(Items iItems = DatePicker,
-                              const QDate iDate = QDate::currentDate(),
-                              QWidget* iParent = 0);
+    explicit KDatePickerPopup(Items iItems,
+                              const QDate iDate,
+                              QWidget* iParent);
 
     /**
        @return A pointer to the private variable mDatePicker, an instance of
