@@ -22,7 +22,7 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 
-#include <QLineEdit>
+#include <qlineedit.h>
 #include "skgbasegui_export.h"
 /**
  * This file is a QLineEdit with calculator included
@@ -62,7 +62,7 @@ public:
      * Default Constructor
      * @param iParent the parent
      */
-    explicit SKGCalculatorEdit(QWidget* iParent = 0);
+    explicit SKGCalculatorEdit(QWidget* iParent);
 
     /**
      * Default Destructor
