@@ -27,9 +27,9 @@
 #include <qprintdialog.h>
 #include <qclipboard.h>
 #include <qapplication.h>
-#include <QDomDocument>
+#include <qdom.h>
 #include <qsvggenerator.h>
-#include <QGraphicsSceneWheelEvent>
+#include <qgraphicssceneevent.h>
 #include <qmath.h>
 #include <qfileinfo.h>
 #include <qwidgetaction.h>
@@ -59,11 +59,11 @@ SKGGraphicsView::SKGGraphicsView(QWidget* iParent)
     m_mainMenu = new QMenu(graphicsView());
 
     // Zoom in menu
-    SKGZoomSelector* zoomMenu = new SKGZoomSelector();
+    auto zoomMenu = new SKGZoomSelector(this);
     zoomMenu->setResetValue(ui.kZoom->resetValue());
     zoomMenu->setValue(ui.kZoom->value());
 
-    QWidgetAction* zoomWidget = new QWidgetAction(this);
+    auto zoomWidget = new QWidgetAction(this);
     zoomWidget->setDefaultWidget(zoomMenu);
     m_mainMenu->addAction(zoomWidget);
 
@@ -101,12 +101,12 @@ SKGGraphicsView::SKGGraphicsView(QWidget* iParent)
 
 SKGGraphicsView::~SKGGraphicsView()
 {
-    m_actShowToolBar = NULL;
-    m_actZoomOriginal = NULL;
-    m_mainMenu = NULL;
-    m_actAntialiasing = NULL;
-    m_actZoomOriginal = NULL;
-    m_actAntialiasing = NULL;
+    m_actShowToolBar = nullptr;
+    m_actZoomOriginal = nullptr;
+    m_mainMenu = nullptr;
+    m_actAntialiasing = nullptr;
+    m_actZoomOriginal = nullptr;
+    m_actAntialiasing = nullptr;
 }
 
 void SKGGraphicsView::setScene(QGraphicsScene* iScene)
@@ -247,7 +247,7 @@ void SKGGraphicsView::onPrint()
 void SKGGraphicsView::onExport()
 {
     _SKGTRACEINFUNC(10);
-    QString fileName = SKGMainPanel::getSaveFileName(QStringLiteral("kfiledialog:///IMPEXP"), QStringLiteral("application/pdf image/svg+xml image/png image/jpeg image/gif image/tiff"), this);
+    QString fileName = SKGMainPanel::getSaveFileName(QStringLiteral("kfiledialog:///IMPEXP"), QStringLiteral("application/pdf image/svg+xml image/png image/jpeg image/gif image/tiff"), this, nullptr);
     if (fileName.isEmpty()) {
         return;
     }
