@@ -55,12 +55,12 @@ void SKGInterfacePlugin::registerGlobalAction(const QString& iIdentifier, QActio
 
 QDockWidget* SKGInterfacePlugin::getDockWidget()
 {
-    return NULL;
+    return nullptr;
 }
 
 SKGTabPage* SKGInterfacePlugin::getWidget()
 {
-    return NULL;
+    return nullptr;
 }
 
 int SKGInterfacePlugin::getNbDashboardWidgets()
@@ -77,17 +77,17 @@ QString SKGInterfacePlugin::getDashboardWidgetTitle(int iIndex)
 SKGBoardWidget* SKGInterfacePlugin::getDashboardWidget(int iIndex)
 {
     Q_UNUSED(iIndex);
-    return NULL;
+    return nullptr;
 }
 
 QWidget* SKGInterfacePlugin::getPreferenceWidget()
 {
-    return NULL;
+    return nullptr;
 }
 
 KConfigSkeleton* SKGInterfacePlugin::getPreferenceSkeleton()
 {
-    return NULL;
+    return nullptr;
 }
 
 SKGError SKGInterfacePlugin::savePreferences() const
