@@ -85,7 +85,7 @@ public:
      * @param iCodec a valid QString to get the codec or nullptr.
      * @return the file name
      */
-    static QString getSaveFileName(const QString& iStartDir, const QString& iFilter, QWidget* iParent, QString* iCodec);
+    static QString getSaveFileName(const QString& iStartDir, const QString& iFilter, QWidget* iParent, QString* iCodec = nullptr);
 
     /**
      * Display an error message
