@@ -833,7 +833,7 @@ QVariant SKGObjectModelBase::computeData(const QModelIndex& iIndex, int iRole) c
             if (!props.isEmpty() && !toolTipString.isEmpty()) {
                 toolTipString += '\n';
             }
-            for (const auto& prop : props) {
+            for (const auto& prop : qAsConst(props)) {
                 if (!toolTipString.isEmpty()) {
                     toolTipString += '\n';
                 }
@@ -963,7 +963,7 @@ QMimeData* SKGObjectModelBase::mimeData(const QModelIndexList& iIndexes) const
     QDataStream stream(&encodedData, QIODevice::WriteOnly);
 
     QString t = getTable();
-    for (const auto& idx : iIndexes) {
+    for (const auto& idx : qAsConst(iIndexes)) {
         if (idx.isValid() && idx.column() == 0) {
             SKGObjectBase obj = getObject(idx);
             t = obj.getRealTable();
