@@ -105,7 +105,7 @@ void SKGShow::setState(const QString& iState)
                 QWidgetAction* wact = qobject_cast<QWidgetAction*>(act);
                 if (wact) {
                     SKGPeriodEdit* pedit = qobject_cast<SKGPeriodEdit*>(wact->defaultWidget());
-                    for (const auto& item : itemsChecked) {
+                    for (const auto& item : qAsConst(itemsChecked)) {
                         if (item.startsWith(identifier % ":")) {
                             pedit->setState(item.right(item.length() - identifier.length() - 1));
                             break;
