@@ -21,7 +21,7 @@
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
-#include <QWidget>
+#include <qwidget.h>
 
 
 
