@@ -21,7 +21,7 @@
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
-#include <QDesignerCustomWidgetCollectionInterface>
+#include <customwidget.h>
 
 
 #include "skgbasegui_export.h"
@@ -39,7 +39,7 @@ public:
      * Constructor
      * @param iParent the parent
      */
-    explicit SKGWidgetCollectionDesignerPlugin(QObject* iParent = 0);
+    explicit SKGWidgetCollectionDesignerPlugin(QObject* iParent = nullptr);
 
     /**
      * To get the list of widgets
