@@ -28,9 +28,9 @@ SKGZoomSelector::SKGZoomSelector(QWidget* iParent)
     ui.setupUi(this);
 
     // Set icons
-    ui.kZoomIn->setIcon(SKGServices::fromTheme("zoom-in"));
-    ui.kZoomOut->setIcon(SKGServices::fromTheme("zoom-out"));
-    ui.kZoomOriginal->setIcon(SKGServices::fromTheme("zoom-original"));
+    ui.kZoomIn->setIcon(SKGServices::fromTheme(QStringLiteral("zoom-in")));
+    ui.kZoomOut->setIcon(SKGServices::fromTheme(QStringLiteral("zoom-out")));
+    ui.kZoomOriginal->setIcon(SKGServices::fromTheme(QStringLiteral("zoom-original")));
 
     // Init timer
     m_timer.setSingleShot(true);
