@@ -28,6 +28,15 @@
 
 #include "skgbasemodeler_export.h"
 
+
+template <typename T> struct QAddConst {
+    typedef const T Type;
+};
+
+// this adds const to non-const objects (like std::as_const)
+template <typename T>
+Q_DECL_CONSTEXPR typename QAddConst<T>::Type& qAsConst(T& t) Q_DECL_NOTHROW { return t; }
+
 /**
  * @var OBJECTSEPARATOR
  * Define the separator between object and subobject
