@@ -53,13 +53,18 @@ public:
     static SKGError getObjectByName(SKGDocument* iDocument, const QString& iTable,
                                     const QString& iName, SKGObjectBase& oObject);
 
+    /**
+     * Default constructor
+     */
+    explicit SKGNamedObject();
+
     /**
      * Constructor
      * @param iDocument the document containing the object
      * @param iTable the table of the object
      * @param iID the identifier in @p iTable of the object
      */
-    explicit SKGNamedObject(SKGDocument* iDocument = NULL, const QString& iTable = QString(), int iID = 0);
+    explicit SKGNamedObject(SKGDocument* iDocument, const QString& iTable = QString(), int iID = 0);
 
     /**
      * Copy constructor
@@ -77,7 +82,7 @@ public:
      * Operator affectation
      * @param iObject the object to copy
      */
-    virtual const SKGNamedObject& operator= (const SKGObjectBase& iObject) Q_DECL_OVERRIDE;
+    virtual const SKGNamedObject& operator= (const SKGObjectBase& iObject) override;
 
     /**
      * Destructor
@@ -104,7 +109,7 @@ protected:
      * For this class, the whereclause is based on name
      * @return the where clause
      */
-    virtual QString getWhereclauseId() const Q_DECL_OVERRIDE;
+    virtual QString getWhereclauseId() const override;
 };
 /**
  * Declare the class
