@@ -22,28 +22,26 @@
 #include "skgnodeobject.h"
 
 #include <klocalizedstring.h>
-#include <QIcon>
+#include <qicon.h>
 
 #include "skgtraces.h"
 #include "skgdefine.h"
 #include "skgdocument.h"
 
-SKGNodeObject::SKGNodeObject(SKGDocument* iDocument, int iID): SKGNamedObject(iDocument, QStringLiteral("v_node"), iID)
-{
-}
+SKGNodeObject::SKGNodeObject(): SKGNodeObject(nullptr)
+{}
+
+SKGNodeObject::SKGNodeObject(SKGDocument* iDocument, int iID): SKGNamedObject(iDocument, QStringLiteral("v_node"), iID), opened(false)
+{}
 
 SKGNodeObject::~SKGNodeObject()
-{
-}
+{}
 
-SKGNodeObject::SKGNodeObject(const SKGNodeObject& iObject)
-    : SKGNamedObject(iObject)
-{
-}
-SKGNodeObject::SKGNodeObject(const SKGObjectBase& iObject)
-    : SKGNamedObject(iObject.getDocument(), QStringLiteral("v_node"), iObject.getID())
-{
-}
+SKGNodeObject::SKGNodeObject(const SKGNodeObject& iObject) : SKGNamedObject(iObject), opened(false)
+{}
+
+SKGNodeObject::SKGNodeObject(const SKGObjectBase& iObject) : SKGNamedObject(iObject.getDocument(), QStringLiteral("v_node"), iObject.getID()), opened(false)
+{}
 
 const SKGNodeObject& SKGNodeObject::operator= (const SKGObjectBase& iObject)
 {
@@ -112,7 +110,7 @@ QIcon SKGNodeObject::getIcon() const
 {
     QStringList overlay;
     if (isAutoStart()) {
-        overlay.push_back(QStringLiteral("user-online"));
+        overlay.push_back(QStringLiteral("media-playback-start"));
     }
     return SKGServices::fromTheme(getAttribute(QStringLiteral("t_icon")) , overlay);
 }
@@ -177,7 +175,7 @@ SKGError SKGNodeObject::createPathNode(SKGDocument* iDocument,
                 }
             }
 
-            IFOKDO(err, oNode.setIcon(QStringLiteral("folder-bookmark")))
+            IFOKDO(err, oNode.setIcon(QStringLiteral("folder-orange")))
             IFOKDO(err, oNode.setOrder(-1))
             IFOKDO(err, oNode.save())
         } else {
@@ -206,7 +204,7 @@ SKGError SKGNodeObject::createPathNode(SKGDocument* iDocument,
                 }
 
                 // save
-                IFOKDO(err, oNode.setIcon(QStringLiteral("folder-bookmark")))
+                IFOKDO(err, oNode.setIcon(QStringLiteral("folder-orange")))
                 IFOKDO(err, oNode.setOrder(-1))
                 IFOKDO(err, oNode.save())
             }
@@ -241,7 +239,7 @@ SKGError SKGNodeObject::setParentNode(const SKGNodeObject& iNode)
     if (iNode.getID() == 0) {
         err = SKGError(ERR_FAIL, i18nc("Error message: Something failed because of a database issue", "%1 failed because linked object is not yet saved in the database.", QStringLiteral("SKGNodeObject::setParentNode")));
     } else {
-        // Check if it's a loop
+        // Check if it is a loop
         SKGNodeObject current = iNode;
         do {
             if (current == *this) {
