@@ -521,11 +521,6 @@ QVariant SKGObjectBase::getPropertyBlob(const QString& iName) const
     return Q_UNLIKELY(!getDocument()) ? QVariant() : getDocument()->getParameterBlob(iName, getUniqueID());
 }
 
-SKGError SKGObjectBase::setProperty(const QString& iName, const QString& iValue, const QString& iFileName) const
-{
-    return setProperty(iName, iValue, iFileName, nullptr);
-}
-
 SKGError SKGObjectBase::setProperty(const QString& iName, const QString& iValue, const QString& iFileName, SKGPropertyObject* oObjectCreated) const
 {
     SKGError err = Q_UNLIKELY(!getDocument()) ? SKGError() : getDocument()->setParameter(iName, iValue, iFileName, getUniqueID(), oObjectCreated);
@@ -536,11 +531,6 @@ SKGError SKGObjectBase::setProperty(const QString& iName, const QString& iValue,
     return err;
 }
 
-SKGError SKGObjectBase::setProperty(const QString& iName, const QString& iValue, const QVariant& iBlob) const
-{
-    return setProperty(iName, iValue, iBlob, nullptr);
-}
-
 SKGError SKGObjectBase::setProperty(const QString& iName, const QString& iValue, const QVariant& iBlob, SKGPropertyObject* oObjectCreated) const
 {
     SKGError err = Q_UNLIKELY(!getDocument()) ? SKGError() :  getDocument()->setParameter(iName, iValue, iBlob, getUniqueID(), oObjectCreated);
