@@ -1464,11 +1464,6 @@ SKGError SKGServices::executeSqliteOrder(QSqlDatabase* iDb, const QString& iSqlO
     return executeSqliteOrder(iDb, iSqlOrder, QMap< QString, QVariant >(), iLastId);
 }
 
-SKGError SKGServices::executeSqliteOrder(QSqlDatabase* iDb, const QString& iSqlOrder)
-{
-    return executeSqliteOrder(iDb, iSqlOrder, nullptr);
-}
-
 SKGError SKGServices::dumpSelectSqliteOrder(QSqlDatabase* iDb, const QString& iSqlOrder, SKGServices::DumpMode iMode)
 {
     return dumpSelectSqliteOrder(iDb, iSqlOrder, nullptr, iMode);
