@@ -461,17 +461,7 @@ public:
      * @return An object managing the error
      *   @see SKGError
      */
-    static SKGError executeSqliteOrder(QSqlDatabase* iDb, const QString& iSqlOrder, int* iLastId);
-
-    /**
-     * Execute a sqlite order
-     * @param iDb a database pointer
-     * @param iSqlOrder the sql order
-     * @param iLastId to retrieve the id of the last created object
-     * @return An object managing the error
-     *   @see SKGError
-     */
-    static SKGError executeSqliteOrder(QSqlDatabase* iDb, const QString& iSqlOrder);
+    static SKGError executeSqliteOrder(QSqlDatabase* iDb, const QString& iSqlOrder, int* iLastId = nullptr);
 
     /**
     * Execute a select sqlite order and return the result in @p oResult
