@@ -100,7 +100,7 @@ class SKGError;
 /**
 * This class manages traces
 */
-class SKGBASEMODELER_EXPORT SKGTraces
+class SKGBASEMODELER_EXPORT SKGTraces final
 {
 public:
     /**
@@ -128,7 +128,7 @@ public:
     /**
     * Destructor
     */
-    virtual ~SKGTraces();
+    ~SKGTraces();
 
     /**
      * Clean profiling statistics
@@ -166,6 +166,7 @@ public:
     static bool SKGPerfo;
 
 private:
+    Q_DISABLE_COPY(SKGTraces)
     void init(int iLevel, const QString& iName, SKGError* iRC);
 
     QString                            m_mame;
