@@ -31,6 +31,7 @@ SKGTransactionMng::SKGTransactionMng(SKGDocument* iDocument,
 {
     m_parentDocument = iDocument;
     m_error = iError;
+    m_errorInBeginTransaction = false;
     if (m_parentDocument && m_error) {
         *m_error = m_parentDocument->beginTransaction(iName, iNbStep, QDateTime::currentDateTime(), iRefreshViews);
         m_errorInBeginTransaction = (m_error->isFailed());
@@ -52,7 +53,7 @@ SKGTransactionMng::~SKGTransactionMng()
                 m_parentDocument->endTransaction(false);
             }
         }
-        m_parentDocument = NULL;
-        m_error = NULL;
+        m_parentDocument = nullptr;
+        m_error = nullptr;
     }
 }
