@@ -21,8 +21,8 @@
  */
 #include "skgxxxplugin.h"
 
-#include <KActionCollection>
-#include <KStandardAction>
+#include <kactioncollection.h>
+#include <kstandardaction.h>
 #include <kaboutdata.h>
 #include <kpluginfactory.h>
 
@@ -36,7 +36,7 @@
 K_PLUGIN_FACTORY(SKGXXXPluginFactory, registerPlugin<SKGXXXPlugin>();)
 
 SKGXXXPlugin::SKGXXXPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) :
-    SKGInterfacePlugin(iParent), m_currentDocument(NULL)
+    SKGInterfacePlugin(iParent), m_currentDocument(nullptr)
 {
     Q_UNUSED(iWidget);
     SKGTRACEINFUNC(10);
@@ -45,7 +45,7 @@ SKGXXXPlugin::SKGXXXPlugin(QWidget* iWidget, QObject* iParent, const QVariantLis
 SKGXXXPlugin::~SKGXXXPlugin()
 {
     SKGTRACEINFUNC(10);
-    m_currentDocument = NULL;
+    m_currentDocument = nullptr;
 }
 
 bool SKGXXXPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
@@ -76,8 +76,8 @@ SKGTabPage* SKGXXXPlugin::getWidget()
 QWidget* SKGXXXPlugin::getPreferenceWidget()
 {
     SKGTRACEINFUNC(10);
-    QWidget* w = new QWidget();
-    ui.setupUi(widget);
+    auto w = new QWidget();
+    ui.setupUi(w);
 
     return w;
 }
@@ -125,4 +125,6 @@ bool SKGXXXPlugin::isInPagesChooser() const
     return true;
 }
 
+#include <skgxxxplugin.moc>
+
 
