@@ -20,7 +20,7 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 
-#include <QDesktopServices>
+#include <qdesktopservices.h>
 
 #include "skgtestmacro.h"
 #include "skgbankincludes.h"
@@ -54,6 +54,9 @@ int main(int argc, char** argv)
         rep->getPortfolio();
         rep->getScheduledOperations();
         rep->getUnitTable();
+        rep->getNetWorth();
+        rep->getAnnualSpending();
+        rep->getPersonalFinanceScore();
 
         QString html;
         SKGTESTERROR(QStringLiteral("SKGReportBank::getReportFromTemplate"), SKGReportBank::getReportFromTemplate(rep, SKGTest::getTestPath(QStringLiteral("IN")) % QStringLiteral("/template.txt"), html), true);
