@@ -602,6 +602,26 @@ int main(int argc, char** argv)
         SKGTESTERROR(QStringLiteral("CSV.getObjects"), document1.getNbObjects(QStringLiteral("suboperation"), QStringLiteral("d_date='2015-07-09'"), nb), true);
         SKGTEST(QStringLiteral("CSV:nb suboperations 2015-07-09"), nb, 1);
     }
+    
+    {
+        // Test import separator comma
+        SKGDocumentBank document1;
+        SKGTESTERROR(QStringLiteral("document1.initialize()"), document1.initialize(), true);
+        SKGError err;
+        {
+            // Scope of the transaction
+            SKGBEGINTRANSACTION(document1, QStringLiteral("IMPORT"), err);
+            SKGImportExportManager imp1(&document1, QUrl::fromLocalFile(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestimportcsv/362231.csv"));
+            SKGTESTERROR(QStringLiteral("CSV.importFile"), imp1.importFile(), true);
+        }
+        int nb = 0;
+        SKGTESTERROR(QStringLiteral("CSV.getObjects"), document1.getNbObjects(QStringLiteral("operation"), QStringLiteral("d_date!='0000-00-00'"), nb), true);
+        SKGTEST(QStringLiteral("CSV:nb operation"), nb, 1);
+        SKGTESTERROR(QStringLiteral("CSV.getObjects"), document1.getNbObjects(QStringLiteral("suboperation"), QStringLiteral("d_date='2016-05-15'"), nb), true);
+        SKGTEST(QStringLiteral("CSV:nb suboperations 2016-05-15"), nb, 1);
+        SKGTESTERROR(QStringLiteral("CSV.getObjects"), document1.getNbObjects(QStringLiteral("suboperation"), QStringLiteral("d_date='2016-05-20'"), nb), true);
+        SKGTEST(QStringLiteral("CSV:nb suboperations 2016-05-20"), nb, 1);
+    }    
     // End test
     SKGENDTEST();
 }
