@@ -190,7 +190,7 @@ int main(int argc, char** argv)
         SKGError err;
         {
             QStringList units = SKGUnitObject::getListofKnownCurrencies(true);
-            for (const auto& unit : units) {
+            for (const auto& unit : qAsConst(units)) {
                 SKGBEGINTRANSACTION(document1, QStringLiteral("UNIT_1"), err);
                 SKGUnitObject unitObj;
                 SKGTESTERROR(QStringLiteral("UNIT:createCurrencyUnit"), SKGUnitObject::createCurrencyUnit(&document1, unit, unitObj), true);
