@@ -140,6 +140,7 @@ int main(int argc, char** argv)
             SKGTESTERROR(QStringLiteral("DOC:save"), document1.save(), true);
 
             SKGTESTERROR(QStringLiteral("DOC:beginTransaction"), document1.beginTransaction(QStringLiteral("tt")), true);
+            SKGTESTERROR(QStringLiteral("DOC:changePassword"), document1.changePassword(QStringLiteral("pwd1")), true);
             SKGTESTERROR(QStringLiteral("DOC:changePassword"), document1.changePassword(QStringLiteral("pwd")), true);
             SKGTESTERROR(QStringLiteral("DOC:setParameter"), document1.setParameter(QStringLiteral("SAVE"), QStringLiteral("1")), true);
             SKGTEST(QStringLiteral("DOC:getParameter"), document1.getParameter(QStringLiteral("SAVE")), QStringLiteral("1"));
@@ -150,7 +151,17 @@ int main(int argc, char** argv)
             SKGDocument document1;
             SKGTESTERROR(QStringLiteral("DOC:load"), document1.load(filename1, QStringLiteral("")), false);
             SKGTEST(QStringLiteral("DOC:load"), document1.load(filename1, QStringLiteral("wrong pwd")).getReturnCode(), ERR_ENCRYPTION);
+
+        }
+        {
+            SKGDocument document1;
             SKGTESTERROR(QStringLiteral("DOC:load"), document1.load(filename1, QStringLiteral("pwd")), true);
+            SKGTESTERROR(QStringLiteral("DOC:beginTransaction"), document1.beginTransaction(QStringLiteral("tt")), true);
+            SKGTESTERROR(QStringLiteral("DOC:changePassword"), document1.changePassword(QStringLiteral("pwd1")), true);
+            SKGTESTERROR(QStringLiteral("DOC:changePassword"), document1.changePassword(QStringLiteral("")), true);
+            SKGTESTERROR(QStringLiteral("DOC:endTransaction"), document1.endTransaction(true), true);
+            SKGTESTERROR(QStringLiteral("DOC:save"), document1.save(), true);
+            SKGTESTERROR(QStringLiteral("DOC:load"), document1.load(filename1, QStringLiteral("")), true);
         }
 
         {
