@@ -23,7 +23,7 @@
  */
 #include <qfile.h>
 #include <qdir.h>
-#include <QCoreApplication>
+#include <qcoreapplication.h>
 
 #include "skgtransactionmng.h"
 #include "skgerror.h"
@@ -89,7 +89,10 @@ public:
  * Exit test
  */
 #define SKGENDTEST()\
-    SKGTRACE << nberror << " errors / " << nbcheck << " checks =" << (100*(static_cast<double>(nberror)) / (static_cast<double>(nbcheck))) << "%" << endl;\
+    if (nbcheck > 0) \
+    { \
+        SKGTRACE << nberror << " errors / " << nbcheck << " checks =" << (100.0*(static_cast<double>(nberror)) / (static_cast<double>(nbcheck))) << "%" << endl;\
+    } \
     SKGTraces::dumpProfilingStatistics();\
     return nberror;
 
@@ -98,7 +101,10 @@ public:
  * Return test
  */
 #define SKGRETURNTEST()\
-    SKGTRACE << nberror << " errors / " << nbcheck << " checks =" << (100*(static_cast<double>(nberror)) / (static_cast<double>(nbcheck))) << "%" << endl;\
+    if (nbcheck > 0) \
+    { \
+        SKGTRACE << nberror << " errors / " << nbcheck << " checks =" << (100.0*(static_cast<double>(nberror)) / (static_cast<double>(nbcheck))) << "%" << endl;\
+    } \
     return nberror;
 
 /**
